@@ -24,269 +24,302 @@ package GCDialogs;
 
 use strict;
 use Gtk2;
+use utf8;
 
 our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
 
+eval 'Gtk2::AboutDialog->set_email_hook(undef, undef)';
+my $hasAboutDialog = ($@ ? 0 : 1);
+
 {
     package GCAboutDialog;
-    use base "Gtk2::Dialog";
+    if (!$hasAboutDialog)
+    {
+        use base "Gtk2::Dialog";
+    }
+    
     sub show
     {
         my $self = shift;
 
-        $self->{value} = undef;
-        $self->{canceled} = 0;
-        $self->SUPER::show();
-        $self->show_all;
-        my $code = $self->run;
-        $self->destroy;
+        if ($hasAboutDialog)
+        {
+            $self->{about}->set_position('center-on-parent');           
+            $self->{about}->run;
+        }
+        else
+        {
+            $self->SUPER::show();
+            $self->show_all;
+            my $code = $self->run;
+            $self->hide;
+        }
+    }
+
+    sub changeStyle
+    {
+        my $self = shift;
+        $self->{vBox}->set_border_width(0);
+        ($self->{vBox}->get_children)[1]->set_border_width($self->{border});
     }
 
     sub new
     {
         my ($proto, $parent, $version) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new($parent->{lang}->{AboutTitle},
+        
+        my $self;
+        
+        my $logoFile = $parent->{logosDir}.'about.png';
+        
+        if ($hasAboutDialog)
+        {
+            $self = {
+                about => new Gtk2::AboutDialog,
+                parent => $parent
+            };
+            bless ($self, $class);
+            
+            open LICENSE, "<".$ENV{GCF_SHARE_DIR}.'/LICENSE';
+            my $license = do {local $/; <LICENSE>};
+            close LICENSE;
+            my @authors = split m/\n/, $parent->{lang}->{AboutWho};
+            
+            $self->{about}->set_transient_for($parent);
+            $self->{about}->set_url_hook( sub {
+                my ($widget, $url) = @_;
+    	        $self->{parent}->openUrl($url);
+            });
+
+            if (-f $logoFile)
+            {
+                my $logo = Gtk2::Gdk::Pixbuf->new_from_file($logoFile);
+                $self->{about}->set_logo($logo);
+            }
+            $self->{about}->set_name('GCfilms');
+            $self->{about}->set_comments($parent->{lang}->{AboutDesc});
+            $self->{about}->set_version($version);
+            $self->{about}->set_authors(@authors);
+            $self->{about}->set_documenters(("",'Tian','http://home.gna.org/gcfilms/doc'));
+            $self->{about}->set_artists("",$parent->{lang}->{AboutDesign}, 'http://le-spektre.org/');
+            $self->{about}->set_copyright($parent->{lang}->{AboutLicense});
+            $self->{about}->set_license($license);
+            $self->{about}->set_translator_credits("\n".$parent->{lang}->{AboutTranslation});
+            $self->{about}->set_website("http://home.gna.org/gcfilms/");
+            $self->{vBox} = $self->{about}->get_children;
+            $self->{border} = $self->{vBox}->get_border_width;
+            if ($self->{about}->signal_query('style_set'))
+            {
+                $self->{about}->signal_connect('style_set' => sub {$self->changeStyle });
+            }
+            $self->changeStyle;
+        }
+        else
+        {
+            $self  = $class->SUPER::new($parent->{lang}->{AboutTitle},
+                                           $parent,
+                                           [qw/modal destroy-with-parent/],
+                                           'gtk-ok' => 'ok'
+                                          );
+            bless ($self, $class);
+    	    my $labelDesc = Gtk2::Label->new($parent->{lang}->{AboutDesc});
+    	    my $labelVersion = Gtk2::Label->new($parent->{lang}->{AboutVersion}.' '.$version);
+    	    #my $labelTeam = Gtk2::Label->new($parent->{lang}->{AboutTeam});
+            
+            my $who = new Gtk2::Label($parent->{lang}->{AboutWho});
+            
+            my $labelTranslation = Gtk2::Label->new($parent->{lang}->{AboutTranslation});
+    	    my $labelLicense = Gtk2::Label->new($parent->{lang}->{AboutLicense});
+    	    $labelLicense->set_justify('center');
+    	    my $button = Gtk2::Button->new_with_mnemonic('_http://home.gna.org/gcfilms/');
+    	    $button->child->set_padding(10,0);
+    	    $button->signal_connect('clicked', sub {
+    	        my ($widget, $parent) = @_;
+    	        (my $url = $widget->get_label) =~ s/^_//;
+    	        $parent->openUrl($url);
+    	    }, $parent);
+       	    my $labelDesign = Gtk2::Label->new($parent->{lang}->{AboutDesign});
+    	    my $designButton = Gtk2::Button->new_with_mnemonic('http://www.le-spektre.org/');
+    	    $designButton->child->set_padding(10,0);
+    	    $designButton->signal_connect('clicked', sub {
+    	        my ($widget, $parent) = @_;
+    	        (my $url = $widget->get_label) =~ s/^_//;
+    	        $parent->openUrl($url);
+    	    }, $parent);
+    
+    	    $self->vbox->set_homogeneous(0);
+    	    if (-f $logoFile)
+            {
+                my $image = Gtk2::Image->new_from_file($logoFile);
+                $self->vbox->pack_start($image, 0, 0, 0);
+            }
+    	    $self->vbox->pack_start($labelDesc, 1, 1, 4);
+    	    $self->vbox->pack_start($labelVersion, 1, 1, 4);
+    	    $self->vbox->pack_start($labelLicense, 1, 1, 4);
+            $self->vbox->pack_start(Gtk2::HSeparator->new, 1, 1, 4);    	    
+    	    my $hbox = new Gtk2::HBox(0,0);
+    	    $hbox->pack_start($button, 1, 0, 10);
+    	    $self->vbox->pack_start($hbox, 0, 0, 4);
+    	    my $hboxDesign = new Gtk2::HBox(0,0);
+    	    $hboxDesign->pack_start($designButton, 1, 0, 10);
+    	    $self->vbox->pack_start($labelDesign, 1, 1, 4);
+    	    $self->vbox->pack_start($hboxDesign, 0, 0, 4);
+    	
+    	    my $teamButton = Gtk2::Button->new($parent->{lang}->{AboutTeam});
+    	    $teamButton->signal_connect('clicked' => sub {
+    	       my $dialog = Gtk2::MessageDialog->new($self,
+							   [qw/modal destroy-with-parent/],
+							   'info',
+							   'ok',
+							   $parent->{lang}->{AboutWho});
+    	       $dialog->run;
+    	       $dialog->destroy;
+    	    });
+    	    $self->action_area->pack_start($teamButton,0,0,0);
+    	    $self->action_area->reorder_child($teamButton,0);
+    	
+    	
+    	    #$self->vbox->set_size_request(400,-1);
+    	    $self->set_resizable(0);
+    		$self->set_position('center-always');
+        }
+
+	    return $self;
+    }
+}
+
+{
+    package GCDependenciesDialog;
+    use base "Gtk2::Dialog";
+
+    sub show
+    {
+        my $self = shift;
+        $self->SUPER::show();
+        $self->show_all;
+        my $code = $self->run;
+        $self->hide;
+    }
+
+    sub checkDependencies
+    {
+        my $self = shift;
+    
+        my $pref = 'GC';
+    
+        my @optionals = ();
+        my $optionalsModules = {};
+    
+        my @files = glob $ENV{GCF_LIB_DIR}.'/*.pm';
+        push @files, glob $ENV{GCF_LIB_DIR}.'/GCPlugins/*.pm';
+        push @files, glob $ENV{GCF_LIB_DIR}.'/GCExport/*.pm';
+        push @files, glob $ENV{GCF_LIB_DIR}.'/GCImport/*.pm';
+        foreach my $file(@files)
+        {
+            open FILE, $file;
+            while (<FILE>)
+            {
+                if ((/eval.*?[\"\']use\s*(.*?)[\"\'];/) && ($1 !~ /base|vars|locale|integer|^lib|utf8|\$opt|strict|^$pref/))
+                #"
+                {
+                    push (@optionals, $1);
+                    push @{$optionalsModules->{$1}}, $file;
+                }
+    
+            }
+            close FILE;
+        }
+    
+        my %saw;
+        @saw{@optionals} = ();
+        @optionals = sort keys %saw;
+    
+        $self->{tableDepend}->resize(1 +  scalar(@optionals),2);
+    
+        my @missings = ();
+        my @oks = ();
+        foreach my $opt(sort @optionals)
+        {
+            my $label1 = new Gtk2::Label($opt);
+            my $label2 = new Gtk2::Label;
+
+            eval "use $opt";
+            if ($@)
+            {
+                my $value;
+                foreach my $module (@{$optionalsModules->{$opt}})
+                {
+                    $module =~ s/.*?GC([^\/]*?)\.pm$/$1/;
+                    $value .= $module.",\n";
+                }
+                $value =~ s/,\n$//;
+                $label2->set_markup("<span color='orange' weight='bold'>".$self->{parent}->{lang}->{InstallMissingFor}." $value</span>");
+                $label2->set_line_wrap(1);
+                $label2->set_justify('left');
+                push @missings, [$label1, $label2];
+            }
+            else
+            {
+                $label2->set_markup("<span color='green' weight='bold'>".$self->{parent}->{lang}->{InstallOK}."</span>");
+                push @oks, [$label1, $label2];
+            }
+
+        }
+
+        my $i = 0;
+        my $labelOpt = new Gtk2::Label;
+        $labelOpt->set_markup('<b>'.$self->{parent}->{lang}->{InstallOptional}.'</b>');
+        $self->{tableDepend}->attach($labelOpt, 0, 2, $i, $i+1, 'expand', 'fill', 0, 10);
+        $i++;
+        
+        foreach (@missings)
+        {
+            $self->{tableDepend}->attach($_->[0], 0, 1, $i, $i+1, 'fill', 'fill', 0, 0);
+            $self->{tableDepend}->attach($_->[1], 1, 2, $i, $i+1, 'fill', 'fill', 0, 0);
+        
+            $i++;
+        }
+        foreach (@oks)
+        {
+            $self->{tableDepend}->attach($_->[0], 0, 1, $i, $i+1, 'fill', 'fill', 0, 0);
+            $self->{tableDepend}->attach($_->[1], 1, 2, $i, $i+1, 'fill', 'fill', 0, 0);
+        
+            $i++;
+        }
+    }
+
+    sub new
+    {
+        my ($proto, $parent) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = $class->SUPER::new($parent->{lang}->{InstallDependencies},
                               $parent,
                               [qw/modal destroy-with-parent/],
                               'gtk-ok' => 'ok'
                               );
-                              
-		my $image = Gtk2::Image->new_from_file($ENV{GCF_SHARE_DIR}.'/icons/gcfilms_logo128.png');
-	    my $label1 = Gtk2::Label->new($parent->{lang}->{AboutDesc});
-	    my $label2 = Gtk2::Label->new($parent->{lang}->{AboutVersion}.' '.$version);
-	    my $label3 = Gtk2::Label->new($parent->{lang}->{AboutTeam});
-        
-        my $who = new Gtk2::Label($parent->{lang}->{AboutWho});
-        
-        my $label4 = Gtk2::Label->new($parent->{lang}->{AboutTranslation});
-	    my $label5 = Gtk2::Label->new($parent->{lang}->{AboutLicense});
-	    my $button = Gtk2::Button->new_with_mnemonic('_http://home.gna.org/gcfilms/');
-	    $button->child->set_padding(10,0);
-	    $button->signal_connect('clicked', sub {
-	        my ($widget, $parent) = @_;
-	        $parent->openUrl($widget->get_label);
-	    }, $parent);
-	    $self->vbox->set_homogeneous(0);
-	    $self->vbox->pack_start($image, 0, 0, 10);
-	    $self->vbox->pack_start($label1, 1, 1, 4);
-	    $self->vbox->pack_start($label2, 1, 1, 4);
-	    $self->vbox->pack_start(Gtk2::HSeparator->new, 1, 1, 4);
-        $self->vbox->pack_start($label3, 1, 1, 4);
-	    $self->vbox->pack_start($who, 1, 1, 4);
-	    $self->vbox->pack_start($label4, 1, 1, 4);
-        $self->vbox->pack_start(Gtk2::HSeparator->new, 1, 1, 4);
-	    $self->vbox->pack_start($label5, 1, 1, 4);
-	    my $hbox = new Gtk2::HBox(0,0);
-	    $hbox->pack_start($button, 1, 0, 10);
-	    $self->vbox->pack_start($hbox, 0, 0, 4);
-	
-	    $self->vbox->set_size_request(320,-1);
-	    $self->set_resizable(0);
-		$self->set_position('center-always');
-	
-	    bless ($self, $class);
-	    return $self;
-    }
-    
-}
+        bless($self, $class);
 
-
-{
-    package GCFileChooserDialog;
-    use Cwd;
-
-    sub new
-    {
-        my ($proto, $title, $parent, $action, $withFilter) = @_;
-        my $class = ref($proto) || $proto;
-        my $self  = {};
-        $self->{action} = $action;
-        $self->{defaultImage} = $ENV{GCF_SHARE_DIR}.'/no.jpg';
         $self->{parent} = $parent;
-        $self->{ignoreFilter} = 1;
-        eval { my $dialog = new Gtk2::FileChooserDialog($title, $parent, $action) };
-        if ($@)
-        {
-            $self->{dialog}  = new Gtk2::FileSelection($title);
-            $self->{dialog}->main_vbox->show_all;
-            my @vboxChildren = $self->{dialog}->main_vbox->get_children;
-            my @buttonBoxChildren = $vboxChildren[0]->get_children;
-            if ($action eq 'select-folder')
-            {
-                $buttonBoxChildren[1]->hide;
-                $buttonBoxChildren[2]->hide;
-                $self->{dialog}->selection_entry->hide;
-                $self->{dialog}->file_list->parent->hide;
-            }
-            elsif ($action eq 'open')
-            {
-                $self->{dialog}->hide_fileop_buttons;
-                $self->{dialog}->selection_entry->set_editable(0);
-            }
-            $self->{type} = 'old';
-        }
-        else
-        {
-            $self->{dialog} = new Gtk2::FileChooserDialog($title, $parent, $action, @GCDialogs::okCancelButtons);
-            $self->{type} = 'new';
-            if ($withFilter)
-            {
-                my $filterAll;
-                $@ = '';
-                eval '$filterAll = new Gtk2::FileFilter';
-                if (!$@)
-                {
-                    $self->{ignoreFilter} = 0;
-                    $filterAll->set_name('*.*');
-                    $filterAll->add_pattern('*.*');
-                    $self->{dialog}->add_filter($filterAll);
-                    $self->{filter} = undef;
-                }
-            }
-        }
-        bless ($self, $class);
+
+        $self->{tableDepend} = new Gtk2::Table(1, 2, 0);
+        $self->{tableDepend}->set_row_spacings(10);
+        $self->{tableDepend}->set_col_spacings(20);
+        $self->{tableDepend}->set_border_width(10);
+        $self->{scrollDepend} = new Gtk2::ScrolledWindow;
+        $self->{scrollDepend}->set_policy ('automatic', 'automatic');
+        $self->{scrollDepend}->add_with_viewport($self->{tableDepend});
+        $self->{scrollDepend}->set_size_request(300, 200);
+        $self->vbox->pack_start($self->{scrollDepend},1,1,10);
+
+        $self->checkDependencies;
+
         return $self;
     }
-
-    sub get_filename
-    {
-        my $self = shift;
-        my $extra = '';
-        $extra = (($^O =~ /win32/i) ? '\\' : '/') if ($self->{action} eq 'select-folder');
-        return $self->{dialog}->get_filename.$extra;
-    }
-
-    sub set_filename
-    {
-        my ($self, $file) = @_;
-        
-        #$file = $ENV{'HOME'}.'/' if ! $file;
-
-		my $dir = getcwd;
-        my $empty = 0;
-        $empty = 1 if !$file;
-        $file = $ENV{HOME}.'/' if !$file;
-		$file = $dir.'/'.$file if (! File::Spec->file_name_is_absolute( $file ));
-        $file =~ s/\//\\/g if ($^O =~ /win32/i);
-        $self->{dialog}->set_filename($file) if !$empty;
-        $self->{dialog}->set_current_folder($file)
-            if (($self->{type} eq 'new') && ($empty));
-        $self->updatePreview($self) if (($self->{type} eq 'old') && ($self->{preview}));
-    }
-
-    sub set_pattern_filter
-    {
-        my ($self, $name, $pattern) = @_;
-        return if $self->{ignoreFilter};
-        if ($self->{type} eq 'new')
-        {
-            $self->{dialog}->remove_filter($self->{filter}) if $self->{filter};        
-            my $filter;
-            eval '$filter = new Gtk2::FileFilter';
-            return if $@;
-            $self->{filter} = $filter;
-            $self->{filter}->set_name($name);
-            $self->{filter}->add_pattern($pattern);
-            $self->{dialog}->add_filter($self->{filter});
-            $self->{dialog}->set_filter($self->{filter});
-        }
-    }
-
-    sub run
-    {
-        my $self = shift;
-        return $self->{dialog}->run if ($self->{action} ne 'save');
-        my $response;
-        while (1)
-        {
-            $response = $self->{dialog}->run;
-            return $response if ($response eq 'cancel');
-            if (-e $self->get_filename)
-            {
-                my  $dialog = Gtk2::MessageDialog->new($self->{dialog},
-                                                       [qw/modal destroy-with-parent/],
-                                                       'question',
-                                                       'yes-no',
-                                                       $self->{parent}->{lang}->{FileOverwrite});
-                my $overwrite = $dialog->run;
-                $dialog->destroy;
-                return $response if ($overwrite eq 'yes');
-            }
-            else
-            {
-                return $response;
-            }
-        }
-    }
-
-    sub hide
-    {
-        my $self = shift;
-        return $self->{dialog}->hide;        
-    }
-
-    sub setWithImagePreview
-    {
-        my ($self, $value) = @_;
-
-        if ($value)
-        {
-            $self->{preview} = Gtk2::Image->new_from_file($self->{defaultImage});
-            if ($self->{type} eq 'new')
-            {
-                $self->{dialog}->signal_connect('update-preview' => \&updatePreview, $self);
-				$self->{dialog}->set_preview_widget($self->{preview});
-				$self->{dialog}->set_preview_widget_active(1);
-            }
-            else
-            {
-                $self->{dialog}->file_list->signal_connect('cursor-changed' => \&updatePreview, $self);
-                $self->{dialog}->file_list->parent->parent->parent->pack_start($self->{preview},0,0,5);
-            }
-            $self->{preview}->show;
-        }
-        else
-        {
-            if ($self->{preview})
-            {
-                $self->{dialog}->file_list->parent->parent->parent->remove($self->{preview}) if ($self->{type} eq 'old');
-                $self->{preview}->destroy;
-                $self->{preview} = undef;
-            }
-        }
-    }
-
-    sub updatePreview
-    {
-        my ($widget, $self) = @_;
-
-        my $file;
-        if ($self->{type} eq 'new')
-        {
-            $file = $self->{dialog}->get_preview_filename;
-        }
-        else
-        {
-            $file = $self->get_filename;
-        }
-        my $pixbuf;
-        eval { $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($file); };
-		$pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($self->{defaultImage}) if ($@);
-		$pixbuf = $pixbuf->scale_simple(120,160,'bilinear') if ($pixbuf->get_width > 120) || ($pixbuf->get_height > 160);
-        $self->{preview}->set_from_pixbuf($pixbuf);
-    }
-
-    sub destroy
-    {
-        my $self = shift;
-        $self->{dialog}->destroy;
-    }
 }
 
 {
     package GCDateSelectionDialog;
-     use base "Gtk2::Dialog";
+    use base "Gtk2::Dialog";
 
     sub show
     {
@@ -349,7 +382,7 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
     {
         my $self = shift;
         
-        $self->setTypes($self->{parent}->{movies}->getTypes);
+        $self->setTypes($self->{parent}->{movies}->getHistory('type'));
         
         $self->SUPER::show();
         $self->show_all;
@@ -449,6 +482,7 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
            $self->saveList(\@{$self->{usedArray}});
         }
         $self->hide;
+        return $response;
     }
     
     
@@ -673,13 +707,13 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
     {
         my $self = shift;
         
-        return $self->{parent}->{lang}->{ExportFieldsUnused};
+        return $self->{parent}->{lang}->{ImportExportFieldsUnused};
     }
     sub getUsedLabel
     {
         my $self = shift;
         
-        return $self->{parent}->{lang}->{ExportFieldsUsed};
+        return $self->{parent}->{lang}->{ImportExportFieldsUsed};
     }           
             
     sub new
@@ -728,13 +762,27 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
     sub selectFile
     {
         my ($widget, $self) = @_;
-        $self->{fileDialog}->set_filename($self->{file}->get_text);
-		my $response = $self->{fileDialog}->run;
+        
+        my $dialog;
+        if ($self->{module}->wantsDirectorySelection)
+        {
+            $dialog = $self->{directoryDialog};
+        }
+        else
+        {
+            $dialog = $self->{fileDialog};
+        }        
+        
+        $dialog->set_filename($self->{file}->get_text);
+        $dialog->set_pattern_filter($self->{module}->getFilePatterns)
+            if ($self->{type} eq 'import');
+        
+		my $response = $dialog->run;
 		if ($response eq 'ok')
 		{
-	            $self->{file}->set_text($self->{fileDialog}->get_filename);
+	            $self->{file}->set_text($dialog->get_filename);
 		}
-        $self->{fileDialog}->hide;
+        $dialog->hide;
     }
 
     sub show
@@ -760,6 +808,8 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
                                                               'error',
                                                               'ok',
                                                               $self->{parent}->{lang}->{ImportExportFieldsEmpty});
+
+                    $dialog->set_position('center-on-parent');
                     $dialog->run();
                     $dialog->destroy;
                     next;
@@ -772,6 +822,8 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
                     $options{file} = $file;
                     $options{lang} = $self->{parent}->{lang};
                     $options{fields} = $self->{fields};
+                    $options{originalList} = $self->{parent}->{movies};
+                    $options{parent} = $self->{parent};
                     
                     my $info = $self->{module}->process(\%options);
                     if ($info)
@@ -781,6 +833,8 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
                                                               'info',
                                                               'ok',
                                                               $info);
+
+                        $dialog->set_position('center-on-parent');
                         $dialog->run();
                         $dialog->destroy ;
                     }
@@ -792,6 +846,8 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
                                                           'error',
                                                           'ok',
                                                           $self->{parent}->{lang}->{ImportExportFileEmpty});
+
+                    $dialog->set_position('center-on-parent');
                     $dialog->run();
                     $dialog->destroy;
                 
@@ -885,6 +941,12 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
                     $in->set_menu($menu);
                 }
                 $widget->pack_start($in, $hExpand,$hExpand,5);
+                if ($option->{buttonLabel})
+                {
+                    my $button = Gtk2::Button->new($self->{lang}->{$option->{buttonLabel}});
+                    $button->signal_connect('clicked' => $option->{buttonCallback}, [$self,$in]);
+                    $widget->pack_start($button, 0, 0, 5);
+                }
             }
             elsif (($type eq 'fileSelection') || ($type eq 'colorSelection'))
             {
@@ -966,8 +1028,6 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
                 $self->{fieldsDialog}->show;
             });
         }
-        $self->{fileDialog}->set_pattern_filter($module->getName, $module->getFilePattern)
-            if ($self->{type} eq 'import');
 
         $self->{options} = \%options;
         $self->{optionsVbox}->show_all;
@@ -1055,6 +1115,7 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
         $type = ($type eq 'import') ? 'open' : 'save';
         my $withFilter = ($self->{type} eq 'import') ? 1 : 0;
         $self->{fileDialog} = new GCFileChooserDialog($parent->{lang}->{ImportExportSave}, $parent, $type, $withFilter);
+        $self->{directoryDialog} = new GCFileChooserDialog($parent->{lang}->{ImportExportSave}, $parent, 'select-folder', 0);
 
         bless ($self, $class);
         return $self;
@@ -1062,5 +1123,235 @@ our @okCancelButtons = ('gtk-cancel'=>'cancel', 'gtk-ok'=>'ok');
     
 }
 
+{
+    package GCFileChooserDialog;
+    use GCGraphicComponents;
+    use File::Basename;
+    use File::Spec;
+
+    sub new
+    {
+        my ($proto, $title, $parent, $action, $withFilter, $autoAppend) = @_;
+        my $class = ref($proto) || $proto;
+        my $self  = {};
+        $self->{action} = $action;
+        $self->{parent} = $parent;
+        $self->{ignoreFilter} = 1;
+        $self->{autoAppend} = 0;
+        eval { my $dialog = new Gtk2::FileChooserDialog($title, $parent, $action) };
+        if ($@)
+        {
+            $self->{dialog}  = new Gtk2::FileSelection($title);
+            $self->{dialog}->main_vbox->show_all;
+            my @vboxChildren = $self->{dialog}->main_vbox->get_children;
+            my @buttonBoxChildren = $vboxChildren[0]->get_children;
+            if ($action eq 'select-folder')
+            {
+                $buttonBoxChildren[1]->hide;
+                $buttonBoxChildren[2]->hide;
+                $self->{dialog}->selection_entry->hide;
+                $self->{dialog}->file_list->parent->hide;
+            }
+            elsif ($action eq 'open')
+            {
+                $self->{dialog}->hide_fileop_buttons;
+                $self->{dialog}->selection_entry->set_editable(0);
+            }
+            $self->{type} = 'old';
+        }
+        else
+        {
+            $self->{dialog} = new Gtk2::FileChooserDialog($title, $parent, $action, @GCDialogs::okCancelButtons);
+            $self->{type} = 'new';
+            if ($withFilter)
+            {
+                $self->{autoAppend} = $autoAppend;
+                my $filterAll;
+                $@ = '';
+                eval '$filterAll = new Gtk2::FileFilter';
+                if (!$@)
+                {
+                    $self->{ignoreFilter} = 0;
+                    $filterAll->set_name('*.*');
+                    $filterAll->add_pattern('*');
+                    $self->{dialog}->add_filter($filterAll);
+                    $self->{filters} = [];
+                }
+            }
+        }
+        bless ($self, $class);
+        return $self;
+    }
+
+    sub transformFilename
+    {
+        my ($self, $file) = @_;
+        
+        if ($self->{autoAppend})
+        {
+            my $tmpFilter = $self->{dialog}->get_filter;
+            if ($tmpFilter)
+            {
+                my $pattern = $self->{filtersPatterns}->{$tmpFilter->get_name};
+                if ($pattern)
+                {
+                    $pattern =~ s/^.*?([^*]*)$/$1/;
+                    $file .= $pattern if $file !~ /\./;
+                }
+            }
+        }
+        return $file;
+    }
+
+    sub get_filename
+    {
+        my $self = shift;
+        my $filename = $self->{dialog}->get_filename;
+        $filename .= (($^O =~ /win32/i) ? '\\' : '/') if ($self->{action} eq 'select-folder');
+        return $self->transformFilename($filename);
+    }
+
+    sub set_filename
+    {
+        my ($self, $file) = @_;
+        
+        my $dir = '.';
+		$dir = dirname($self->{parent}->{options}->file)
+		if ($self->{parent}->{options})
+		&& ($self->{parent}->{options}->file);
+        my $empty = 0;
+        $empty = 1 if !$file;
+        $file = $ENV{HOME}.'/' if !$file;
+		$file = $dir.'/'.$file if (! File::Spec->file_name_is_absolute( $file ));
+        $file =~ s/\//\\/g if ($^O =~ /win32/i);
+        $file = File::Spec->canonpath($file);
+        $self->{dialog}->set_filename($file) if (!$empty && !(-d $file));
+        $self->{dialog}->set_current_folder($file.'/')
+            if (($self->{type} eq 'new') && 
+               (($empty) || (-d $file)));
+        if ($self->{preview})
+        {
+            $self->updatePreview($self) if ($self->{type} eq 'old');
+            $self->{preview}->setImage($file) if ($self->{type} eq 'new');
+        }
+    }
+
+    sub set_pattern_filter
+    {
+        my ($self, @filters) = @_;
+        return if $self->{ignoreFilter};
+        if ($self->{type} eq 'new')
+        {
+            $self->{dialog}->remove_filter($_) foreach(@{$self->{filters}});
+            $self->{filters} = [];
+            $self->{filtersPatterns} = {};
+            foreach (@filters)
+            {
+                my $filter;
+                eval '$filter = new Gtk2::FileFilter';
+                return if $@;
+                $filter->set_name($_->[0]);
+                $filter->add_pattern($_->[1]);
+                push @{$self->{filters}}, $filter;
+                $self->{dialog}->add_filter($filter);
+                $self->{filtersPatterns}->{$_->[0]} = $_->[1];
+            }
+            $self->{dialog}->set_filter($self->{filters}->[0]) if $self->{filters}->[0];
+        }
+    }
+
+    sub run
+    {
+        my $self = shift;
+        return $self->{dialog}->run if ($self->{action} ne 'save');
+        my $response;
+        while (1)
+        {
+            $response = $self->{dialog}->run;
+            return $response if ($response ne 'ok');
+            my $filename = $self->get_filename;
+            if (-e $filename)
+            {
+                my  $dialog = Gtk2::MessageDialog->new($self->{dialog},
+                                                       [qw/modal destroy-with-parent/],
+                                                       'question',
+                                                       'yes-no',
+                                                       $self->{parent}->{lang}->{FileOverwrite});
+
+                $dialog->set_position('center-on-parent');
+                my $overwrite = $dialog->run;
+                $dialog->destroy;
+                return $response if ($overwrite eq 'yes');
+            }
+            else
+            {
+                return $response;
+            }
+        }
+    }
+
+    sub hide
+    {
+        my $self = shift;
+        return $self->{dialog}->hide;        
+    }
+
+    sub setWithImagePreview
+    {
+        my ($self, $value) = @_;
+
+        if ($value)
+        {
+            #$self->{preview} = Gtk2::Image->new_from_file($self->{defaultImage});
+            $self->{preview} = new GCMovieImage($self->{parent}->{options}, $self->{parent}->{defaultImage},1);
+            if ($self->{type} eq 'new')
+            {
+                $self->{dialog}->signal_connect('update-preview' => \&updatePreview, $self);
+				$self->{dialog}->set_preview_widget($self->{preview});
+				$self->{dialog}->set_preview_widget_active(1);
+            }
+            else
+            {
+                $self->{dialog}->file_list->signal_connect('cursor-changed' => \&updatePreview, $self);
+                $self->{dialog}->file_list->parent->parent->parent->pack_start($self->{preview},0,0,5);
+            }
+            $self->{preview}->show;
+        }
+        else
+        {
+            if ($self->{preview})
+            {
+                $self->{dialog}->file_list->parent->parent->parent->remove($self->{preview}) if ($self->{type} eq 'old');
+                $self->{preview}->destroy;
+                $self->{preview} = undef;
+            }
+        }
+    }
+
+    sub updatePreview
+    {
+        my ($widget, $self, $other) = @_;
+        my $file;
+        if ($self->{type} eq 'new')
+        {
+            eval
+            {
+                $file = $self->{dialog}->get_preview_filename;
+            }
+        }
+        else
+        {
+            $file = $self->get_filename;
+        }
+        $self->{preview}->setImage($file) if $file;
+    }
+
+    sub destroy
+    {
+        my $self = shift;
+        $self->{dialog}->destroy;
+    }
+}
+
 
 1;
