@@ -32,6 +32,8 @@
     our %lang = (
 
         'LangName' => 'Deutsch',
+
+        'Separator' => ': ',
         
         'Warning' => '<b>Warnung</b>:
         
@@ -43,6 +45,8 @@ der Seite <b>verboten</b>.
 
 Der Button unter den Filminformationen verweist Sie auf die 
 jeweilige Webseite, von der die Informationen stammen.',
+
+    'AllMoviesFiltered' => 'Kein Film erfüllt Ihre Filtereinstellungen.',
         
 	'InstallDirInfo' => 'Installiere nach ',
 	'InstallMandatory' => 'Erforderliche Komponenten',
@@ -54,12 +58,19 @@ jeweilige Webseite, von der die Informationen stammen.',
 	'InstallLaunch' => 'Um die Anwendung zu verwenden starten Sie ',
 	'InstallDirectory' => 'Basisverzeichnis',
 	'InstallTitle' => 'Installation von GCfilms',
-	'InstallDependancies' => 'Abhängigkeiten',
-	'InstallToggleDependancies' => 'Anzeigen/Verbergen der Abhängigkeiten',
+	'InstallDependencies' => 'Abhängigkeiten',
+    'InstallPath' => 'Pfad',
+    'InstallOptions' => 'Optionen',
 	'InstallSelectDirectory' => 'Wählen Sie ein Basisverzeichnis für die Installation',
 	'InstallWithClean' => 'Daten im Installationsverzeichnis löschen',
-	'InstallWithMenu' => 'Add GCfilms to Applications menu',
-	'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
+	'InstallWithMenu' => 'GCfilms zum Anwendungsmenü hinzufügen',
+    'InstallNoPermission' => 'Fehler: Sie haben keine Rechte um im gewählten Verzeichnis zu schreiben',
+	'InstallMissingMandatory' => 'Notwendige Abhängigkeiten fehlen auf ihrem System. Sie müssen diese auf ihrem System ergänzen, um Gcfilms installieren zu können.',
+	'InstallMissingOptional' => 'Einige unten aufgelistete optionale Abhängigkeiten fehlen. GCfilms kann installiert werden, aber einige Features werden nicht verfügbar sein.',
+	'InstallMissingNone' => 'Es gibt keine fehlenden Abhängigkeiten. Sie können mit der Installation fortfahren.',
+	'InstallOK' => 'OK',
+	'InstallMissing' => 'Fehlt',
+	'InstallMissingFor' => 'Fehlt für',
 
 #Splash
 	'SplashInit' => 'Initialisiere',
@@ -75,6 +86,7 @@ jeweilige Webseite, von der die Informationen stammen.',
 		'MenuExport' => '_Exportieren',
 
 	'MenuEdit'  => '_Bearbeiten',
+   	    'MenuDuplicate' => 'Film _duplizieren',
 		'MenuEditDeleteCurrent' => 'Film _entfernen',
 		'MenuEditLockMovies' => 'Filmliste _sperren',
 
@@ -121,6 +133,7 @@ jeweilige Webseite, von der die Informationen stammen.',
         'Movies' => 'Filme',
         'PreferencesTooltip' => 'Ändern der Programmeinstellungen',
         'ViewTooltip' => 'Anzeige der Filmliste ändern',
+        'PlayTooltip' => 'Mit dem Film verknüpftes Video abspielen',
 
         'StatusSearch' => 'Suche...',
         'StatusGetInfo' => 'Lade Informationen...',
@@ -146,14 +159,19 @@ jeweilige Webseite, von der die Informationen stammen.',
         'AboutWho' => 'Tian : Projektmanager, Programmierer
 MeV : Programmierer
 Christophe Z : Programmierer
-rootII : Programmierer
+Adolfo González : Programmierer
+
+Jason Day : Mitarbeiter
+Gabriel Meier : Mitarbeiter
 
 Dab : Mitarbeiter
-Jason Day : Mitarbeiter
-Infinito : Mitarbeiter
-VFRMania : Mitarbeiter',
-        'AboutLicense' => 'Veröffentlicht unter den Bedingungen der  GNU GPL',
+rootII : Programmierer
+VFRMania : Mitarbeiter,',
+        'AboutLicense' => 'Veröffentlicht unter den Bedingungen der GNU GPL
+Logos Copyright le Spektre
+http://le-spektre.org',
         'AboutTranslation' => 'Deutsche Übersetzung von Gabriel Meier',
+        'AboutDesign' => 'Logo und webdesign von le Spektre',
         
         'ToolbarRandom' => 'Heute Abend',
         
@@ -166,14 +184,18 @@ VFRMania : Mitarbeiter',
         
         'OptionsTitle' => 'Einstellungen',
         'OptionsBrowser' => 'Web-Browser',
+        'OptionsPlayer' => 'Video-Player',
         'OptionsImages' => 'Verzeichnis für Bilder',
+        'OptionsUseRelativePaths' => 'Relative Pfade für Bilder verwenden',
         'OptionsOrder' => 'Layout',
         'OptionsStatus' => 'Statusleiste am unteren Fensterrand anzeigen',
         'OptionsUrlPicture' => 'Seitenlogo auf dem Button zur Anzeige der Informationswebseite anzeigen',
         'OptionsWarning' => 'Warnung: Die Einstellungen in diesem Panel werden erst nach dem Neustart der Anwendung wirksam!',
         'OptionsTabs' => 'Tabs',
-        'OptionsInfo' => 'Allgemeine Informationen zuerst',
-        'OptionsPerso' => 'Details zuerst',
+        'OptionsAllInOne' => 'All In One',
+        'OptionsCompact' => 'Compact',
+        'OptionsReadOnly' => 'Read Only',
+        'OptionsWebSite' => 'GCfilms Website',
         'OptionsRemoveConfirm' => 'Löschen von Filmen bestätigen lassen',
         'OptionsAutoSave' => 'Filmliste automatisch speichern',
         'OptionsSplash' => 'Splash-Screen anzeigen',
@@ -194,6 +216,8 @@ VFRMania : Mitarbeiter',
         'OptionsDisplay' => 'Anzeige',
         'OptionsToolbar' => 'Toolbar',
         'OptionsToolbars' => {0 => 'Keine', 1 => 'Klein', 2 => 'Gross'},
+        'OptionsToolbarPosition' => 'Position',
+        'OptionsToolbarPositions' => {0 => 'Oben', 1 => 'Unten', 2 => 'Links', 3 => 'Rechts'},
         'OptionsView' => 'Listenansicht',
         'OptionsViews' => {0 => 'Text', 1 => 'Bilder', 2 => 'Detailliert'},
         'OptionsColumns' => 'Spalten',
@@ -205,19 +229,38 @@ VFRMania : Mitarbeiter',
         'OptionsFormats' => 'Medien (getrennt durch Kommata)',
         'OptionsSearchStop' => 'Suche kann abgebrochen werden',
         'OptionsAlwaysOriginal' => 'Titel statt Originaltitel verwenden, wenn dieser nicht vorhanden ist',
-        'OptionsSelectColor' => 'Farbe wählen',
-        'OptionsImagesBg' => 'Hintergrund',
-        'OptionsImagesBgPicture' => 'Hintergrundbild verwenden',
-        'OptionsImagesFg'=> 'Auswahl',
-        'OptionsImagesBgTooltip' => 'Hintergrundfarbe und -bild ändern',
-        'OptionsImagesFgTooltip'=> 'Farbe für die Auswahl einstellen',
         'OptionsHistory' => 'Größe des Verlaufs',
         'OptionsClearHistory' => 'Verlauf löschen',
 		'OptionsStyle' => 'Skin',
-		'OptionsDetailsFields' => 'Felder',
-		'OptionsDetailsTitle' => 'Anzuzeigende Felder wählen',
+        'OptionsDontAsk' => 'Nicht mehr fragen',
+
+        'ImagesOptionsButton' => 'Einstellungen',
+        'ImagesOptionsTitle' => 'Einstellungen für die Bilderliste',
+        'ImagesOptionsSelectColor' => 'Farbe wählen',
+        'ImagesOptionsBg' => 'Hintergrund',
+        'ImagesOptionsBgPicture' => 'Hintergrundbild verwenden',
+        'ImagesOptionsFg'=> 'Auswahl',
+        'ImagesOptionsBgTooltip' => 'Hintergrundfarbe ändern',
+        'ImagesOptionsFgTooltip'=> 'Farbe für die Auswahl einstellen',
+        'ImagesOptionsSizeLabel' => 'Größe',
+        'ImagesOptionsSizeList' => {0 => 'Sehr klein', 1 => 'Klein', 2 => 'Mittel', 3 => 'Groß', 4 => 'Sehr Groß'},
+        'ImagesOptionsSizeTooltip' => 'Bildgröße auswählen',
 		        
+        'DetailedOptionsTitle' => 'Einstellungen für die detaillierte Liste',
+        'DetailedOptionsImageSize' => 'Bildgröße',
+        'DetailedOptionsGroupMovies' => 'Filme in Sammlungen gruppieren',
+		'DetailedOptionsFields' => 'Anzuzeigende Felder wählen',
+
+        'ExtractButton' => 'Information',
+        'ExtractTitle' => 'Dateiinformationen',
+        'ExtractSize' => 'Größe',
+        'ExtractLength' => 'Laufzeit (minuten)',
+        'ExtractType' => 'Videoformat',
+        'ExtractAudioEncoding' => 'Audioformat',
+        'ExtractImport' => 'Werte verwenden',
+
         'ExportTitle' => 'Filmliste exportieren',
+        'ExportFilter' => 'Nur angezeigte Filme exportieren',
         'ImportListTitle' => 'Eine weitere Filmliste importieren',
         'ImportExportFile' => 'Datei',
         'ImportExportSave' => 'Bitte wählen Sie die zu verwendende Datei',
@@ -238,38 +281,23 @@ VFRMania : Mitarbeiter',
 
         'PanelSearchButton' => 'Internetsuche',
         'PanelSearchTip' => 'Im Internet nach Informationen zu diesem Titel suchen',
-        'PanelSeen' => 'Gesehen',
-        'PanelRating' => 'Bewertung: ',
-        'PanelMedia' => 'Format: ',
-        'PanelNumber' => 'Nummer: ',
-        'PanelPlace' => 'Ort:',
+        'PanelSeenYes' => 'Film bereits gesehen',
+        'PanelSeenNo' => 'Film noch nicht gesehen',
         'PanelLanguages' => 'Sprachen',
-        'PanelAudio' => 'Audio',
         'PanelEncoding' => 'Codierung',
-        'PanelSub' => 'Untertitel',
-        'PanelComment' => 'Kommentare:',
-        'PanelOriginal' => 'Originaltitel: ',
-        'PanelImageTip' => 'Klicken, um das Bild zu ändern',
+        'PanelImageTip' => 'Klicken, um das Bild zu ändern. Rechtsklick für weitere Optionen.',
         'PanelImageTitle' => 'Wählen Sie ein Bild',
+        'PanelTrailerTitle' => 'Datei auswählen',
         'PanelInfoFrame' => 'Informationen',
-        'PanelDate' => 'Datum: ',
-        'PanelDirector' => 'Regisseur: ',
-        'PanelTime' => 'Länge: ',
-        'PanelCountry' => 'Land: ',
-        'PanelAge' => 'Altersfreigabe: ',
         'PanelAgeUnknown' => 'Unbewertet',
         'PanelAgeNone' => 'Jedes Alter',
         'PanelAgeParent' => 'Aufsicht der Eltern',
-        'PanelType' => 'Genre: ',
-        'PanelActors' => 'Besetzung: ',
-        'PanelDescription' => 'Beschreibung:',
-        'PanelLendDate' => 'Verliehen am:',
-        'PanelBorrower' => 'Entleiher:',
         'PanelNobody' => 'Niemand',
         'PanelUnknown' => 'Unbekannt',
+        'PanelLendedYes' => 'Verliehen',
+        'PanelLendedNo' => 'Verfügbar',
         'PanelLendDateSelect' => 'Wählen Sie ein Datum',
         'PanelReturned' => 'Film zurückgegeben',
-        'PanelHistory' => 'Verlauf',
         'PanelRemove' =>'Entfernen',
         'PanelClear' =>'Löschen',
         'PanelReturnDate' => 'Rückgabedatum',
@@ -297,6 +325,7 @@ VFRMania : Mitarbeiter',
         'PluginsName' => 'Name',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Sprache',
+        'PluginsUseSite' => 'Gewählte Seite für zukünftige Suchen verwenden',
 
         'BorrowersTitle' => 'Entleiher bearbeiten',
         'BorrowersName' => 'Name',
@@ -334,60 +363,44 @@ VFRMania : Mitarbeiter',
         'SearchSeenYes' => 'Ja',
         'SearchSeenNo' => 'Nein',
         'SearchAge' => 'Altersfreigabe:',
+        'SearchYear' => 'Jahr zwischen',
+        'SearchYearBetween' => 'und',
 
         'RenameTitle' => 'Genres bearbeiten',
         'RenameOld' => 'Bisheriger Name',
         'RenameNew' => 'Neuer Name',
         
-        'ImportTitle' => 'Wählen Sie die zu importierenden Felder',
-        'ImportMovieTitle' => 'Titel',
-        'ImportDate' => 'Datum',
-        'ImportTime' => 'Länge',
-        'ImportDirector' => 'Regisseur',
-        'ImportNat' => 'Land',
-        'ImportAge' => 'Altersfreigabe',
-        'ImportOrig' => 'Originaltitel',
-        'ImportActors' => 'Besetzung',
-        'ImportSynopsis' => 'Beschreibung',
-        'ImportAudio' => 'Audio',
-        'ImportSubt' => 'Untertitel',
-        'ImportImage' => 'Bild',
+        'ImportWindowTitle' => 'Wählen Sie die zu importierenden Felder',
         'ImportViewPicture' => 'Bild ansehen',
-        'ImportType' => 'Genre',
         'ImportSelectAll' => 'Alles auswählen',
         'ImportSelectNone' => 'Nichts auswählen',
 
         'ExportTarGzInfo' => 'Archiv erstellt: ',
 
         'ExportHTMLWithJS' => 'Javascript verwenden',
+      	'ExportHTMLFileTemplate' => 'Template:',
+        'ExportHTMLPreview' => 'Vorschau',
+        'ExportHTMLNoPreview' => 'Keine Vorschau verfügbar',
         'ExportHTMLTitle' => 'Seitentitel',
         'ExportHTMLInfoFile' => 'Filmliste erstellt: ',
         'ExportHTMLInfoDir' => 'Bilder gespeichert unter: ',
         'ExportHTMLHeightimg' => 'Höhe der zu exportierende Bilder (in Pixeln): ',
-        'ExportHTMLnote' => 'Liste erstellt mit <a href="https://gna.org/projects/gcfilms/">GCfilms</a>',
-        'ExportHTMLinputTitle' => 'Suchtext eingeben',
-        'ExportHTMLlistSearchTypeValue1' => 'Nur Titel',
-        'ExportHTMLlistSearchTypeValue2' => 'Alle Informationen',
-        'ExportHTMLsearchbutton' => 'Suche',    
-        'ExportHTMLsearchbuttonTitle' => 'Nur Filme anzeigen die diesen Kriterien entsprechen',
-        'ExportHTMLallbutton' => 'Alle',
-        'ExportHTMLallbuttonTitle' => 'Alle Filme anzeigen',
-        'ExportHTMLviewinfos' => 'Alle maximieren',
-        'ExportHTMLviewinfosTitle' => 'Alle Filminformationen anzeigen',
-        'ExportHTMLhideinfos' => 'Alle minimieren',
-        'ExportHTMLhideinfosTitle' => 'Nur Titel anzeigen',
+        'ExportHTMLOpenFileInBrowser' => 'Erzeugte Datei im Webbrowser öffnen',
+        'ExportHTMLNote' => 'Liste erstellt mit <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
+        'ExportHTMLInputTitle' => 'Suchtext eingeben',
+        'ExportHTMLSearchType1' => 'Nur Titel',
+        'ExportHTMLSearchType2' => 'Alle Informationen',
+        'ExportHTMLSearchButton' => 'Suche',    
+        'ExportHTMLSearchTitle' => 'Nur Filme anzeigen die diesen Kriterien entsprechen',
+        'ExportHTMLAllButton' => 'Alle',
+        'ExportHTMLAllTitle' => 'Alle Filme anzeigen',
+        'ExportHTMLExpand' => 'Alle maximieren',
+        'ExportHTMLExpandTitle' => 'Alle Filminformationen anzeigen',
+        'ExportHTMLCollapse' => 'Alle minimieren',
+        'ExportHTMLCollapseTitle' => 'Nur Titel anzeigen',
         'ExportHTMLBorrowed' => 'Ausgeliehen von: ',
-        'ExportHTMLnoBorrowed' => 'Verfügbar',
-        'ExportHTMLtop' => 'Top',
-        'ExportHTMLtableTime' => 'Länge',
-        'ExportHTMLtableType' => 'Genre',
-        'ExportHTMLtableDate' => 'Datum',
-        'ExportHTMLtableDirector' => 'Regisseur',
-        'ExportHTMLtableActors' => 'Besetzung',
-        'ExportHTMLtableFormat' => 'Format',
-        'ExportHTMLtableRating' => 'Bewertung',
-        'ExportHTMLtableAudio' => 'Audio',
-        'ExportHTMLtableSubtitle' => 'Untertitel',
+        'ExportHTMLNotBorrowed' => 'Verfügbar',
+        'ExportHTMLTop' => 'Top',
         
         'ExportSQLWithPictures' => 'Bilder in ein Unterverzeichnis kopieren',
         'ExportSQLWithDrop' => 'Exportiere mit DROP Anweisung',
@@ -400,8 +413,6 @@ VFRMania : Mitarbeiter',
         'ExportXMLModels' => 'Zu verwendende Vorlage',
         'ExportXMLUseFile' => 'Datei verwenden',
         'ExportXMLUseModel' => 'Textvorlage verwenden',
-	
-	'ExportHTMLFileTemplate' => 'Template :',
 
         'ExportCSVHeader' => 'Feldnamen im Header exportieren',
         'ExportCSVSeparator' => 'Separator',
@@ -416,6 +427,8 @@ VFRMania : Mitarbeiter',
         'ImportListCommentSite' => 'Webseite: ',
         'ImportListCommentTitle' => 'Titel: ',
 
+        'ImportTellicoNotVideo' => 'Datei ist keine Tellico Video-Sammlung',
+
         'MultiSiteTitle' => 'Seite für Internetrecherche',
         'MultiSiteUnused' => 'Nicht verwendete Plugins',
         'MultiSiteUsed' => 'Zu verwendende Plugins',
@@ -430,6 +443,7 @@ VFRMania : Mitarbeiter',
             time => 'Allgemein: Länge',
             director => 'Allgemein: Regisseur',
             nat => 'Allgemein: Land',
+            age => 'Allgemein: Altersfreigabe',
             type => 'Allgemein: Genre',
             image => 'Allgemein: Bild',
             orig => 'Allgemein: Originaltitel',
@@ -442,6 +456,10 @@ VFRMania : Mitarbeiter',
             format => 'Details: Format',
             url => 'Details: Internetseite',
             place => 'Details: Ort',
+            video => 'Details: Video format',
+            trailer => 'Détails : Video file',
+            collection => 'Details: Sammlung',
+            rank => 'Details: Teil/Folge',
             audio => 'Details: Audio',
             subt => 'Details: Untertitel',
             borrower => 'Verleih: Entleiher',
@@ -454,38 +472,13 @@ VFRMania : Mitarbeiter',
         'DisplayOptionsMain' => 'Wichtigste Felder',
         'DisplayOptionsActions' => 'Buttons am Seitenende',
         'DisplayOptionsSearch' => 'Suchbutton',
-        'DisplayOptionsId' => 'Filmkennung',
-        'DisplayOptionsInfo' => 'Allgemein',
-        'DisplayOptionsPerso' => 'Details',
-        'DisplayOptionsBorrowings' => 'Verleih',
-        'DisplayOptionsSeen' => 'Gesehen',
-        'DisplayOptionsRating' => 'Bewertung',
-        'DisplayOptionsFormat' => 'Format',
-        'DisplayOptionsNumber' => 'Anzahl',
-        'DisplayOptionsPlace' => 'Ort',
-        'DisplayOptionsAudio' => 'Audio Sprachen',
-        'DisplayOptionsSubt' => 'Untertitel Sprachen',
-        'DisplayOptionsComment' => 'Kommentare',
-        'DisplayOptionsOrig' => 'Originaltitel',
-        'DisplayOptionsImage' => 'Bild',
-        'DisplayOptionsDate' => 'Datum',
-        'DisplayOptionsDirector' => 'Regisseur',
-        'DisplayOptionsAge' => 'Altersfreigabe',
-        'DisplayOptionsTime' => 'Länge',
-        'DisplayOptionsNat' => 'Land',
-        'DisplayOptionsType' => 'Genre',
-        'DisplayOptionsActors' => 'Besetzung',
-        'DisplayOptionsSynopsis' => 'Beschreibung',
-        'DisplayOptionsBorrower' => 'Entleiher',
-        'DisplayOptionsLendDate' => 'Verleihdatum',
-        'DisplayOptionsMail' => 'E-Mail senden',
-        'DisplayOptionsHistory' => 'Verlauf',
 
         'GenresTitle' => 'Genre konvertieren',
         'GenresCategoryName' => 'Verwendete Genres',
         'GenresCategoryMembers' => 'Zu ersetzende Genres',
         'GenresLoad' => 'Lade eine Liste',
         'GenresExport' => 'Liste in Datei speichern',
+        'GenresModify' => 'Genre bearbeiten',
     );
 }
 1;
