@@ -33,6 +33,8 @@
 
         'LangName' => 'English',
         
+        'Separator' => ': ',
+        
         'Warning' => '<b>Warning</b>:
         
 Information downloaded from web sites (through the 
@@ -44,22 +46,31 @@ Any redistribution is forbidden without the site\'s
 To determine which site owns the information, you
 may use the <b>button below movie details</b>.',
         
+        'AllMoviesFiltered' => 'No movie matches your filtering criteria',
+        
 	'InstallDirInfo' => 'Installing in ',
 	'InstallMandatory' => 'Mandatory components',
 	'InstallOptional' => 'Optional Components',
-	'InstallErrorMissing' => 'Error : Following components have to be installed: ',
+	'InstallErrorMissing' => 'Error : Following Perl components have to be installed: ',
 	'InstallPrompt' => 'Base directory for installation [/usr/local]: ',
 	'InstallEnd' => 'End of the installation',
 	'InstallNoError' => 'No error',
 	'InstallLaunch' => 'To use this application, one can launch ',
 	'InstallDirectory' => 'Base directory',
 	'InstallTitle' => 'GCfilms installation',
-	'InstallDependancies' => 'Dependencies',
-	'InstallToggleDependancies' => 'Show/Hide dependencies',
+	'InstallDependencies' => 'Dependencies',
+    'InstallPath' => 'Path',
+    'InstallOptions' => 'Options',
 	'InstallSelectDirectory' => 'Select base directory for the installation',
 	'InstallWithClean' => 'Remove files found in installation directory',
 	'InstallWithMenu' => 'Add GCfilms to Applications menu',
 	'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
+	'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCfilms until they have been added to your system.',
+	'InstallMissingOptional' => 'Some optional dependencies are missing. There are listed under. GCfilms may be installed but some features won\'t be available.',
+	'InstallMissingNone' => 'There are no missing dependency. You may continue and install GCfilms.',
+	'InstallOK' => 'OK',
+	'InstallMissing' => 'Missing',
+	'InstallMissingFor' => 'Missing for',
 
 #Splash
 	'SplashInit' => 'Initialization',
@@ -75,6 +86,7 @@ may use the <b>button below movie details</b>.',
 		'MenuExport' => '_Export',
 
 	'MenuEdit'  => '_Edit',
+   	    'MenuDuplicate' => '_Duplicate movie',
 		'MenuEditDeleteCurrent' => '_Remove Movie',
 		'MenuEditLockMovies' => '_Lock Collection',
 
@@ -121,6 +133,7 @@ may use the <b>button below movie details</b>.',
         'Movies' => 'Movies',
         'PreferencesTooltip' => 'Set your preferences',
         'ViewTooltip' => 'Change collection display',
+        'PlayTooltip' => 'Play video associated to the movie',
 
         'StatusSearch' => 'Search in progress...',
         'StatusGetInfo' => 'Getting information...',
@@ -143,18 +156,23 @@ may use the <b>button below movie details</b>.',
         'AboutDesc' => 'Gtk2 Movie Catalog',
         'AboutVersion' => 'Version',
         'AboutTeam' => 'Team',
-        'AboutWho' => 'Tian : Project manager, Programmer
-MeV : Programmer
-Christophe Z : Programmer
-rootII : Programmer
+        'AboutWho' => 'Tian: Project manager, Programmer
+MeV: Programmer
+Christophe Z: Programmer
+Adolfo González : Programmer
+
+Jason Day : Contributer
+Gabriel Meier : Contributer
 
 Dab : Contributer
-Jason Day : Contributer
-Infinito : Contributer
+rootII : Contributer
 VFRMania : Contributer',
-        'AboutLicense' => 'Distributed under the terms of the GNU GPL',
+        'AboutLicense' => 'Distributed under the terms of the GNU GPL
+Logos Copyright le Spektre
+http://le-spektre.org',
         'AboutTranslation' => 'English translation by Tian and Jason Day',
-        
+        'AboutDesign' => 'Logo and webdesign by le Spektre',
+
         'ToolbarRandom' => 'Tonight',
         
         'ResultsTitle' => 'Select a movie',
@@ -166,14 +184,18 @@ VFRMania : Contributer',
         
         'OptionsTitle' => 'Preferences',
         'OptionsBrowser' => 'Web browser',
+        'OptionsPlayer' => 'Video player',
         'OptionsImages' => 'Images directory',
+        'OptionsUseRelativePaths' => 'Use relative paths for images',
         'OptionsOrder' => 'Layout',
         'OptionsStatus' => 'Display status bar',
         'OptionsUrlPicture' => 'Display site logo on button used to display movie\'s webpage',
         'OptionsWarning' => 'Warning: Changes in this tab won\'t take effect until the application is restarted.',
         'OptionsTabs' => 'Tabs',
-        'OptionsInfo' => 'General Information First',
-        'OptionsPerso' => 'Details First',
+        'OptionsAllInOne' => 'All In One',
+        'OptionsCompact' => 'Compact',
+        'OptionsReadOnly' => 'Read Only',
+        'OptionsWebSite' => 'GCfilms Website',
         'OptionsRemoveConfirm' => 'Ask confirmation before movie deletion',
         'OptionsAutoSave' => 'Automatically save collection',
         'OptionsSplash' => 'Show splash screen',
@@ -194,6 +216,8 @@ VFRMania : Contributer',
         'OptionsDisplay' => 'Display',
         'OptionsToolbar' => 'Toolbar',
         'OptionsToolbars' => {0 => 'None', 1 => 'Small', 2 => 'Large'},
+        'OptionsToolbarPosition' => 'Position',
+        'OptionsToolbarPositions' => {0 => 'Top', 1 => 'Bottom', 2 => 'Left', 3 => 'Right'},
         'OptionsView' => 'Display',
         'OptionsViews' => {0 => 'Text', 1 => 'Image', 2 => 'Detailed'},
         'OptionsColumns' => 'Columns',
@@ -205,19 +229,38 @@ VFRMania : Contributer',
         'OptionsFormats' => 'Media types (Comma separated)',
         'OptionsSearchStop' => 'Allow search to be aborted',
         'OptionsAlwaysOriginal' => 'Use main title as the original title if none present',
-        'OptionsSelectColor' => 'Select a color',
-        'OptionsImagesBg' => 'Background',
-        'OptionsImagesBgPicture' => 'Use a background picture',
-        'OptionsImagesFg'=> 'Selection',
-        'OptionsImagesBgTooltip' => 'Change background color and image',
-        'OptionsImagesFgTooltip'=> 'Change selection color',
         'OptionsHistory' => 'Size of history',
         'OptionsClearHistory' => 'Clear history',
 		'OptionsStyle' => 'Skin',
-		'OptionsDetailsFields' => 'Fields',
-		'OptionsDetailsTitle' => 'Select fields to display',
+        'OptionsDontAsk' => 'Don\'t ask anymore',
+
+        'ImagesOptionsButton' => 'Settings',
+        'ImagesOptionsTitle' => 'Settings for images list',
+        'ImagesOptionsSelectColor' => 'Select a color',
+        'ImagesOptionsBg' => 'Background',
+        'ImagesOptionsBgPicture' => 'Use a background picture',
+        'ImagesOptionsFg'=> 'Selection',
+        'ImagesOptionsBgTooltip' => 'Change background color',
+        'ImagesOptionsFgTooltip'=> 'Change selection color',
+        'ImagesOptionsSizeLabel' => 'Size',
+        'ImagesOptionsSizeList' => {0 => 'Very Small', 1 => 'Small', 2 => 'Medium', 3 => 'Large', 4 => 'Extra Large'},
+        'ImagesOptionsSizeTooltip' => 'Select image size',
 		        
+        'DetailedOptionsTitle' => 'Settings for detailed list',
+        'DetailedOptionsImageSize' => 'Images size',
+        'DetailedOptionsGroupMovies' => 'Group movies by collection',
+		'DetailedOptionsFields' => 'Select fields to display',
+
+        'ExtractButton' => 'Information',
+        'ExtractTitle' => 'Video file information',
+        'ExtractSize' => 'Size',
+        'ExtractLength' => 'Runtime (minutes)',
+        'ExtractType' => 'Video format',
+        'ExtractAudioEncoding' => 'Audio format',
+        'ExtractImport' => 'Use values',
+
         'ExportTitle' => 'Export movie list',
+        'ExportFilter' => 'Export only displayed movies',
         'ImportListTitle' => 'Import another movies list',
         'ImportExportFile' => 'File',
         'ImportExportSave' => 'Please select file to use',
@@ -238,38 +281,23 @@ VFRMania : Contributer',
 
         'PanelSearchButton' => 'Fetch Information',
         'PanelSearchTip' => 'Search web for information on this title',
-        'PanelSeen' => 'Viewed',
-        'PanelRating' => 'Rating: ',
-        'PanelMedia' => 'Media: ',
-        'PanelNumber' => 'Number: ',
-        'PanelPlace' => 'Place:',
+        'PanelSeenYes' => 'Viewed',
+        'PanelSeenNo' => 'Not viewed',
         'PanelLanguages' => 'Languages',
-        'PanelAudio' => 'Audio',
         'PanelEncoding' => 'Encoding',
-        'PanelSub' => 'Subtitles',
-        'PanelComment' => 'Comments:',
-        'PanelOriginal' => 'Original title: ',
-        'PanelImageTip' => 'Click on the picture to select different one',
+        'PanelImageTip' => 'Click on the picture to select different one. Right click for more options.',
         'PanelImageTitle' => 'Select a picture',
+        'PanelTrailerTitle' => 'Select a file',
         'PanelInfoFrame' => 'Information',
-        'PanelDate' => 'Date: ',
-        'PanelDirector' => 'Director: ',
-        'PanelTime' => 'Length: ',
-        'PanelCountry' => 'Country: ',
-        'PanelAge' => 'Minimum age: ',
         'PanelAgeUnknown' => 'Unrated',
         'PanelAgeNone' => 'All Ages',
         'PanelAgeParent' => 'Parental Guidance',
-        'PanelType' => 'Genre: ',
-        'PanelActors' => 'Cast: ',
-        'PanelDescription' => 'Synopsis:',
-        'PanelLendDate' => 'Lend date:',
-        'PanelBorrower' => 'Borrower:',
         'PanelNobody' => 'Nobody',
         'PanelUnknown' => 'Unknown',
+        'PanelLendedYes' => 'Lended',
+        'PanelLendedNo' => 'Available',
         'PanelLendDateSelect' => 'Select a Date',
         'PanelReturned' => 'Movie Returned',
-        'PanelHistory' => 'History',
         'PanelRemove' =>'Remove',
         'PanelClear' =>'Clear',
         'PanelReturnDate' => 'Return date',
@@ -297,6 +325,7 @@ VFRMania : Contributer',
         'PluginsName' => 'Name',
         'PluginsAuthor' => 'Author',
         'PluginsLang' => 'Language',
+        'PluginsUseSite' => 'Use selected site for future searches',
 
         'BorrowersTitle' => 'Borrower Configuration',
         'BorrowersName' => 'Name',
@@ -334,60 +363,44 @@ VFRMania : Contributer',
         'SearchSeenYes' => 'Yes',
         'SearchSeenNo' => 'No',
         'SearchAge' => 'Audience age:',
+        'SearchYear' => 'Year betweeen',
+        'SearchYearBetween' => 'and',
 
         'RenameTitle' => 'Edit Genres',
         'RenameOld' => 'Current name',
         'RenameNew' => 'New name',
         
-        'ImportTitle' => 'Select Fields to be Imported',
-        'ImportMovieTitle' => 'Title',
-        'ImportDate' => 'Date',
-        'ImportTime' => 'Length',
-        'ImportDirector' => 'Director',
-        'ImportNat' => 'Country',
-        'ImportAge' => 'Minimum age',
-        'ImportOrig' => 'Original title',
-        'ImportActors' => 'Cast',
-        'ImportSynopsis' => 'Synopsis',
-        'ImportAudio' => 'Audio',
-        'ImportSubt' => 'Subtitles',
-        'ImportImage' => 'Picture',
+        'ImportWindowTitle' => 'Select Fields to be Imported',
         'ImportViewPicture' => 'View picture',
-        'ImportType' => 'Genre',
         'ImportSelectAll' => 'Select all',
         'ImportSelectNone' => 'Select none',
 
         'ExportTarGzInfo' => 'Archive is in file: ',
 
         'ExportHTMLWithJS' => 'Use Javascript',
+       	'ExportHTMLFileTemplate' => 'Template :',
+        'ExportHTMLPreview' => 'Preview',
+        'ExportHTMLNoPreview' => 'No preview available',
         'ExportHTMLTitle' => 'Page title',
         'ExportHTMLInfoFile' => 'Movies list is in file: ',
         'ExportHTMLInfoDir' => 'Images are in: ',
         'ExportHTMLHeightimg' => 'Height (in pixels) of the image to be exported: ',
-        'ExportHTMLnote' => 'List generated by <a href="https://gna.org/projects/gcfilms/">GCfilms</a>',
-        'ExportHTMLinputTitle' => 'Enter search text',
-        'ExportHTMLlistSearchTypeValue1' => 'Title only',
-        'ExportHTMLlistSearchTypeValue2' => 'Full information',
-        'ExportHTMLsearchbutton' => 'Search',    
-        'ExportHTMLsearchbuttonTitle' => 'Display only movies matching previous criteria',
-        'ExportHTMLallbutton' => 'All',
-        'ExportHTMLallbuttonTitle' => 'Display all movies',
-        'ExportHTMLviewinfos' => 'Expand all',
-        'ExportHTMLviewinfosTitle' => 'Display all movies information',
-        'ExportHTMLhideinfos' => 'Collapse all',
-        'ExportHTMLhideinfosTitle' => 'Collapse all movies information',
+        'ExportHTMLOpenFileInBrowser' => 'Open generated file in web browser',
+        'ExportHTMLNote' => 'List generated by <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
+        'ExportHTMLInputTitle' => 'Enter search text',
+        'ExportHTMLSearchType1' => 'Title only',
+        'ExportHTMLSearchType2' => 'Full information',
+        'ExportHTMLSearchButton' => 'Search',    
+        'ExportHTMLSearchTitle' => 'Display only movies matching previous criteria',
+        'ExportHTMLAllButton' => 'All',
+        'ExportHTMLAllTitle' => 'Display all movies',
+        'ExportHTMLExpand' => 'Expand all',
+        'ExportHTMLExpandTitle' => 'Display all movies information',
+        'ExportHTMLCollapse' => 'Collapse all',
+        'ExportHTMLCollapseTitle' => 'Collapse all movies information',
         'ExportHTMLBorrowed' => 'Borrowed by: ',
-        'ExportHTMLnoBorrowed' => 'Available',
-        'ExportHTMLtop' => 'Top',
-        'ExportHTMLtableTime' => 'Length',
-        'ExportHTMLtableType' => 'Genre',
-        'ExportHTMLtableDate' => 'Date',
-        'ExportHTMLtableDirector' => 'Director',
-        'ExportHTMLtableActors' => 'Cast',
-        'ExportHTMLtableFormat' => 'Support',
-        'ExportHTMLtableRating' => 'Rating',
-        'ExportHTMLtableAudio' => 'Audio',
-        'ExportHTMLtableSubtitle' => 'Subtitles',
+        'ExportHTMLNotBorrowed' => 'Available',
+        'ExportHTMLTop' => 'Top',
         
         'ExportSQLWithPictures' => 'Copy pictures in a sub-directory',
         'ExportSQLWithDrop' => 'Include DROP instruction',
@@ -400,8 +413,6 @@ VFRMania : Contributer',
         'ExportXMLModels' => 'Template to use',
         'ExportXMLUseFile' => 'Use file',
         'ExportXMLUseModel' => 'Use text area',
-	
-	'ExportHTMLFileTemplate' => 'Template :',
 
         'ExportCSVHeader' => 'Include fields names on the top',
         'ExportCSVSeparator' => 'Separator',
@@ -416,6 +427,8 @@ VFRMania : Contributer',
         'ImportListCommentSite' => 'Website: ',
         'ImportListCommentTitle' => 'Title: ',
 
+        'ImportTellicoNotVideo' => 'File is not a Tellico video collection',
+
         'MultiSiteTitle' => 'Sites to use for searches',
         'MultiSiteUnused' => 'Unused plugins',
         'MultiSiteUsed' => 'Plugins to be used',
@@ -430,6 +443,7 @@ VFRMania : Contributer',
             time => 'General: Length',
             director => 'General: Director',
             nat => 'General: Country',
+            age => 'General: Minimum age',
             type => 'General: Genre',
             image => 'General: Picture',
             orig => 'General: Original title',
@@ -443,6 +457,10 @@ VFRMania : Contributer',
             url => 'Details: Web',
             place => 'Details: Location',
             audio => 'Details: Audio',
+            video => 'Details: Video format',
+            trailer => 'Details : Video file',
+            collection => 'Details: Collection',
+            rank => 'Details: Rank',
             subt => 'Details: Subtitles',
             borrower => 'Lending: Borrower',
             lendDate => 'Lending: Out Since',
@@ -454,38 +472,13 @@ VFRMania : Contributer',
         'DisplayOptionsMain' => 'Main items',
         'DisplayOptionsActions' => 'Action buttons',
         'DisplayOptionsSearch' => 'Search button',
-        'DisplayOptionsId' => 'Movie identifier',
-        'DisplayOptionsInfo' => 'General',
-        'DisplayOptionsPerso' => 'Details',
-        'DisplayOptionsBorrowings' => 'Lending',
-        'DisplayOptionsSeen' => 'Viewed',
-        'DisplayOptionsRating' => 'Rating',
-        'DisplayOptionsFormat' => 'Media',
-        'DisplayOptionsNumber' => 'Number',
-        'DisplayOptionsPlace' => 'Location',
-        'DisplayOptionsAudio' => 'Audio Languages',
-        'DisplayOptionsSubt' => 'Subtitle Languages',
-        'DisplayOptionsComment' => 'Comments',
-        'DisplayOptionsOrig' => 'Original Title',
-        'DisplayOptionsImage' => 'Picture',
-        'DisplayOptionsDate' => 'Date',
-        'DisplayOptionsDirector' => 'Director',
-        'DisplayOptionsAge' => 'Minimum age',
-        'DisplayOptionsTime' => 'Length',
-        'DisplayOptionsNat' => 'Country',
-        'DisplayOptionsType' => 'Genre',
-        'DisplayOptionsActors' => 'Cast',
-        'DisplayOptionsSynopsis' => 'Synopsis',
-        'DisplayOptionsBorrower' => 'Borrower',
-        'DisplayOptionsLendDate' => 'Out since',
-        'DisplayOptionsMail' => 'Send an email',
-        'DisplayOptionsHistory' => 'History',
 
         'GenresTitle' => 'Genre Conversion',
         'GenresCategoryName' => 'Genre to use',
         'GenresCategoryMembers' => 'Genre to replace',
         'GenresLoad' => 'Load a list',
         'GenresExport' => 'Save list to a file',
+        'GenresModify' => 'Edit conversion',
     );
 }
 1;
