@@ -32,8 +32,10 @@
     our %lang = (
 
         'LangName' => 'Español',
+        
+        'Separator' => ' : ',
 
-        'Warning' => '<b>Aviso</b>:
+        'Warning' => '<b>Aviso</b> :
 
 La información descargada desde Internet (gracias a
 los plugins de búsqueda) es sólo para <b>uso personal</b>
@@ -41,25 +43,34 @@ los plugins de búsqueda) es sólo para <b>uso personal</b>
 Cualquier redistribución queda prohibida <b> sin la
 explícita autorización de las respectivas webs</b>.
 
-Para saver cual es la web a la que pertenece la información,
-puedes usar <b>el botón debajo de los detalles de la película</b>.',
-        
+Para saber cual es la web a la que pertenece la información,
+puede usar <b>el botón situado debajo de los detalles de la película</b>.',
+
+        'AllMoviesFiltered' => 'Ninguna películas cumple con los criterios de filtrado',
+
         'InstallDirInfo' => 'Instalar en ',
         'InstallMandatory' => 'Componentes obligatorios',
         'InstallOptional' => 'Componentes opcionales',
-        'InstallErrorMissing' => 'Error: los componentes siguientes deben instalarse : ',
+        'InstallErrorMissing' => 'Error : los componentes siguientes deben instalarse : ',
         'InstallPrompt' => 'Directorio predeterminado para la instalación [/usr/local] : ',
         'InstallEnd' => 'Fin de la instalación',	
         'InstallNoError' => 'Ningún error',
         'InstallLaunch' => 'Para utilizar la aplicación, ejecute ',
         'InstallDirectory' => 'Repertorio básico',
         'InstallTitle' => 'Instalación de GCfilms',
-        'InstallDependancies' => 'Dependencias',	
-        'InstallToggleDependancies' => 'Indicar o encubrir las dependencias',
+        'InstallDependencies' => 'Dependencias',	
+        'InstallPath' => 'Ruta',
+        'InstallOptions' => 'Opciones',
         'InstallSelectDirectory' => 'Elija el directorio para la instalación',   
         'InstallWithClean' => 'Eliminar archivos del directorio de instalación.',
        	'InstallWithMenu' => 'Añadir GCfilms al menu de Aplicaciones',
-       	'InstallNoPermission' => 'Error: No tiene permisos para instalar en el directorio seleccionado!!',
+       	'InstallNoPermission' => 'Error : No tiene permisos para instalar en el directorio seleccionado!!',
+        'InstallMissingMandatory' => 'Algunas dependencias obligatorias no están disponibles. No podrá instalar GCfilms hasta que se instalen en el sistema.',
+        'InstallMissingOptional' => 'Algunas depencias opcionales no están disponibles. Se detallan debajo. GCfilms se instalará con algunas funciones deshabilitadas.',
+        'InstallMissingNone' => 'Dependencias satisfechas. Puede continuar e instalar GCfilms.',
+        'InstallOK' => 'OK',
+        'InstallMissing' => 'No disponible',
+        'InstallMissingFor' => 'No disponible por',
         
         'SplashInit' => 'Inicialización',
         'SplashLoad' => 'Cargando películas',
@@ -76,6 +87,7 @@ puedes usar <b>el botón debajo de los detalles de la película</b>.',
         'Movies' => 'Películas',
         'PreferencesTooltip' => 'Cambiar sus preferencias',
         'ViewTooltip' => 'Cambiar el tipo de lista',
+        'PlayTooltip' => 'Reproducir archivo de video asociado a la película',
         
         'StatusSearch' => 'Búsqueda en curso...',
         'StatusGetInfo' => 'Descargando la información...',
@@ -102,14 +114,19 @@ puedes usar <b>el botón debajo de los detalles de la película</b>.',
         'AboutWho' => 'Tian : Gestión del proyecto, Programación
 MeV : Programación
 Christophe Z : Programación
-rootII : Programación
+Adolfo González : Programación
+
+Jason Day : Contribución
+Gabriel Meier : Contribución
 
 Dab : Contribución
-Jason Day : Contribución
-Infinito : Contribución
+rootII : Programación
 VFRMania : Contribución',
-        'AboutLicense' => 'Distribuido según los términos de la GNU GPL',
+        'AboutLicense' => 'Distribuido según los términos de la GNU GPL
+Logos Copyright le Spektre
+http://le-spektre.org',
         'AboutTranslation' => 'Traducción : Henon Aurore y Adolfo González',
+        'AboutDesign' => 'Logo y diseño web por le Spektre',
         
         'ToolbarRandom' => 'Esta noche',
 
@@ -122,14 +139,18 @@ VFRMania : Contribución',
 
         'OptionsTitle' => 'Preferencias',
         'OptionsBrowser' => 'Navegador de Internet',
+        'OptionsPlayer' => 'Reproductor de video',
         'OptionsImages' => 'Directorio de imágenes', 	
+        'OptionsUseRelativePaths' => 'Usar rutas relativas para las imágenes',
         'OptionsOrder' => 'Disposición',		
         'OptionsStatus' => 'Barra de estado',	
         'OptionsUrlPicture' => 'Mostrar el logo de la web usada para obtener la información',
         'OptionsWarning' => 'Cuidado : Los cambios efectuados en este pestaña no se tendrán en cuenta hasta reiniciar la aplicación', 
         'OptionsTabs' => 'Pestañas',
-        'OptionsInfo' => 'Ficha de la películas en primer lugar',	
-        'OptionsPerso' => 'Información personal en primer lugar',	
+        'OptionsAllInOne' => 'Todo en Uno',
+        'OptionsCompact' => 'Compacto',
+        'OptionsReadOnly' => 'Sólo Lectura',
+        'OptionsWebSite' => 'GCfilms Website',
         'OptionsRemoveConfirm' => 'Pedir confirmación antes de eliminar',
         'OptionsAutoSave' => 'Protección automática de la lista de películas',
         'OptionsSplash' => 'Mostrar la pantalla de arranque', 
@@ -150,6 +171,8 @@ VFRMania : Contribución',
         'OptionsDisplay' => 'Visualización',
         'OptionsToolbar' => 'Barra de herramientas',	
         'OptionsToolbars' => {0 => 'Ninguna', 1 => 'Pequeña', 2 => 'Grande'},
+        'OptionsToolbarPosition' => 'Posición',
+        'OptionsToolbarPositions' => {0 => 'Arriba', 1 => 'Abajo', 2 => 'Izquierda', 3 => 'Derecha'},
         'OptionsView' => 'Visualización de las películas',
         'OptionsViews' => {0 => 'Texto', 1 => 'Imagen', 2 => 'Detallada'},
         'OptionsColumns' => 'Columnas',	
@@ -161,19 +184,38 @@ VFRMania : Contribución',
 	'OptionsFormats' => 'Tipo de soportes (separados por una coma)',
         'OptionsSearchStop' => 'El usuario puede parar las búsquedas',
         'OptionsAlwaysOriginal' => 'Usar título principal como el original si no se encuentra ninguno',
-        'OptionsSelectColor' => 'Elija un color',
-        'OptionsImagesBg' => 'Fondo',
-        'OptionsImagesBgPicture' => 'Usar una imagen de fondo',
-        'OptionsImagesFg'=> 'Selección',
-        'OptionsImagesBgTooltip' => 'Cambiar el color de fondo',
-        'OptionsImagesFgTooltip'=> 'Cambiar el color de la selección',
         'OptionsHistory' => 'Tamaño del historial',
         'OptionsClearHistory' => 'Limpiar el historial',
-	'OptionsStyle' => 'Skin',
-	'OptionsDetailsFields' => 'Campos',
-	'OptionsDetailsTitle' => 'Seleccione los campos a mostrar',
+        'OptionsStyle' => 'Piel',
+        'OptionsDontAsk' => 'No preguntar nunca más',
 		       
+		'ImagesOptionsButton' => 'Preferencias',
+        'ImagesOptionsTitle' => 'Preferencias para el listado de imágenes',
+        'ImagesOptionsSelectColor' => 'Elija un color',
+        'ImagesOptionsBg' => 'Fondo',
+        'ImagesOptionsBgPicture' => 'Usar una imagen de fondo',
+        'ImagesOptionsFg'=> 'Selección',
+        'ImagesOptionsBgTooltip' => 'Cambiar el color de fondo',
+        'ImagesOptionsFgTooltip'=> 'Cambiar el color de la selección',
+        'ImagesOptionsSizeLabel' => 'Tamaño',
+        'ImagesOptionsSizeList' => {0 => 'Muy Pequeño', 1 => 'Pequeño', 2 => 'Mediano', 3 => 'Grande', 4 => 'Extra Grande'},
+        'ImagesOptionsSizeTooltip' => 'Seleccione el tamaño de imagen',
+
+        'DetailedOptionsTitle' => 'Preferencias del listado detallado',
+        'DetailedOptionsImageSize' => 'Tamaño de la imagen',
+        'DetailedOptionsGroupMovies' => 'Agrupar películas por serie',
+        'DetailedOptionsFields' => 'Seleccione los campos a mostrar',
+
+        'ExtractButton' => 'Información',
+        'ExtractTitle' => 'Información del Fichero de Video',
+        'ExtractSize' => 'Tamaño',
+        'ExtractLength' => 'Duración (minutos)',
+        'ExtractType' => 'Formato de Video',
+        'ExtractAudioEncoding' => 'Formato de Audio',
+        'ExtractImport' => 'Usar valores',
+
         'ExportTitle' => 'Exportar el listado de películas',	
+        'ExportFilter' => 'Exportar sólo las películas mostradas',
         'ImportListTitle' => 'Importar otro listado de películas',
         'ImportExportFile' => 'Fichero',	 
         'ImportExportSave' => '¿En qué fichero guardar?', 	
@@ -194,41 +236,26 @@ VFRMania : Contribución',
 
         'PanelSearchButton' => 'Descargar',
         'PanelSearchTip' => 'Buscar información relativa a la película',
-        'PanelSeen' => 'Película ya vista',	
-        'PanelRating' => 'Nota : ',	
-        'PanelMedia' => 'Soporte : ',	
-        'PanelNumber' => 'Número : ',	
-        'PanelPlace' => 'Sitio :',	
+        'PanelSeenYes' => 'Película ya vista',
+        'PanelSeenNo' => 'Película no vista',
         'PanelLanguages' => 'Idiomas :',		
-        'PanelAudio' => 'Audio',
-        'PanelEncoding' => 'Codificación',
-        'PanelSub' => 'Subtítulos',
-        'PanelComment' => 'Comentarios :',	
-        'PanelOriginal' => 'Título original : ',	
-        'PanelImageTip' => 'Pulse en la imagen para elegir otra',	
+        'PanelEncoding' => 'Codificación :',
+        'PanelImageTip' => 'Pulse en la imagen para elegir otra. Click con el botón derecho para mas opciones.',
         'PanelImageTitle' => 'Seleccionar una imagen',	
+        'PanelTrailerTitle' => 'Seleccione un fichero',
         'PanelInfoFrame' => 'Informacion',	
-        'PanelDate' => 'Fecha de salida : ',	
-        'PanelDirector' => 'Director : ',	
-        'PanelTime' => 'Duración : ',	
-        'PanelCountry' => 'Nacionalidad : ',	
-        'PanelAge' => 'Edad mínima: ',
         'PanelAgeUnknown' => 'Desconocida',
         'PanelAgeNone' => 'Ninguna',
         'PanelAgeParent' => 'Control paterno',
-        'PanelType' => 'Géneros : ',	
-        'PanelActors' => 'Actores : ',	
-        'PanelDescription' => 'Sinopsis :',	
-        'PanelLendDate' => 'Fecha de préstamo',	
-        'PanelBorrower' => 'Prestatario',	
         'PanelNobody' => 'Nadie',	
         'PanelUnknown' => 'Desconocido',	
+        'PanelLendedYes' => 'Prestada',
+        'PanelLendedNo' => 'Disponible',
         'PanelLendDateSelect' => 'Cambiar la fecha',	
         'PanelReturned' => 'Película devuelta',	
-        'PanelHistory' => 'Historial',
         'PanelRemove' =>'Eliminar',	
         'PanelClear' =>'Vacíar',	
-        'PanelReturnDate' => 'Fecha de devolución',	
+        'PanelReturnDate' => 'Fecha de devolución',
         'PanelWeb' => 'Ver la ficha en Internet',
         'PanelWebTip' => 'Ver la ficha de la película en Internet',	
         'PanelRemoveTip' => 'Eliminar la película anteriormente mencionada', 
@@ -261,9 +288,10 @@ VFRMania : Contribución',
         'MenuAgeNone' => 'Todas la edades',
         'MenuAgeParent' => 'Requiere control paterno',
         'MenuAgeLess' => 'Con edad mínima...',
-	'MenuEdit'  => '_Editar',
-	'MenuEditDeleteCurrent' => '_Eliminar película actual',
-	'MenuEditLockMovies' => '_Bloquear la información',
+        'MenuEdit'  => '_Editar',
+   	    'MenuDuplicate' => '_Duplicar película',
+        'MenuEditDeleteCurrent' => '_Eliminar película actual',
+        'MenuEditLockMovies' => '_Bloquear la información',
         'MenuDisplay' => '_Visualización',
         'MenuConfiguration' => '_Configuración',	
         'MenuDisplayOptions' => '_Información a mostrar',
@@ -291,6 +319,7 @@ VFRMania : Contribución',
         'PluginsName' => 'Nombre',
         'PluginsAuthor' => 'Autor',
         'PluginsLang' => 'Idioma',
+        'PluginsUseSite' => 'Usar sitio seleccionado para futuras búsquedas',
         
         'BorrowersTitle' => 'Configuración de los prestatarios',	
         'BorrowersName' => 'Nombre',	
@@ -328,64 +357,44 @@ VFRMania : Contribución',
         'SearchSeenYes' => 'Sí',	
         'SearchSeenNo' => 'No',	
         'SearchAge' => 'Edad mínima',
+        'SearchYear' => 'Año entre',
+        'SearchYearBetween' => 'y',
                 
         'RenameTitle' => 'Renombrar una categoría',	
         'RenameOld' => 'Nombre actual',	
         'RenameNew' => 'Nuevo nombre',	
         
-        'ImportTitle' => 'Elegir los campos que deben importarse',	
-
-        'ImportMovieTitle' => 'Título',	
-        'ImportDate' => 'Fecha',	
-        'ImportTime' => 'Duración',	
-        'ImportDirector' => 'Director',	
-        'ImportNat' => 'Nacionalidad',	
-        'ImportAge' => 'Edad mínima',
-        'ImportOrig' => 'Título original',	
-        'ImportActors' => 'Actores',	
-        'ImportSynopsis' => 'Sinopsis',	
-        'ImportAudio' => 'Audio',
-        'ImportSubt' => 'Subtítulos',
-        'ImportImage' => 'Imagen',		
+        'ImportWindowTitle' => 'Elegir los campos que deben importarse',	
         'ImportViewPicture' => 'Ver la imagen',		
-        'ImportType' => 'Géneros',	
         'ImportSelectAll' => 'Seleccionarlo todo',	
         'ImportSelectNone' => 'No seleccionar nada',  
 
         'ExportTarGzInfo' => 'El archivo .tar.gz se encuentra en : ',
 
         'ExportHTMLWithJS' => 'Utilizar Javascript',
+        'ExportHTMLFileTemplate' => 'Plantilla :',
+        'ExportHTMLPreview' => 'Vista previa',
+        'ExportHTMLNoPreview' => 'Vista previa no disponible',
         'ExportHTMLTitle' => 'Título de la página',
         'ExportHTMLInfoFile' => 'El listado se encuentra en el archivo : ',
         'ExportHTMLInfoDir' => 'Las imágenes se encuentran en : ',
         'ExportHTMLHeightimg' => 'Altura en pixels de las imágenes a exportar : ',
-        'ExportHTMLnote' => 'Listado generado con <a href="https://gna.org/projects/gcfilms/">GCfilms</a>',
-        'ExportHTMLinputTitle' => 'Introduzca el texto a buscar',
-        'ExportHTMLlistSearchTypeValue1' => 'Sólo el Título',
-        'ExportHTMLlistSearchTypeValue2' => 'Toda la información',
-        'ExportHTMLsearchbutton' => 'Buscar',
-        'ExportHTMLsearchbuttonTitle' => 'Mostrar sólo las películas coincidentes con los criterios anteriores',
-        'ExportHTMLallbutton' => 'Todas',
-        'ExportHTMLallbuttonTitle' => 'Mostrar todas las películas',
-        'ExportHTMLviewinfos' => 'Todos desplegados',
-        'ExportHTMLviewinfosTitle' => 'Mostrar la información de todas las películas',
-        'ExportHTMLhideinfos' => 'Todos plegados',
-        'ExportHTMLhideinfosTitle' => 'Ocultar la información de todas las películas',
+        'ExportHTMLOpenFileInBrowser' => 'Abrir el fichero generado en el navegador web',
+        'ExportHTMLNote' => 'Listado generado con <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
+        'ExportHTMLInputTitle' => 'Introduzca el texto a buscar',
+        'ExportHTMLSearchType1' => 'Sólo el Título',
+        'ExportHTMLSearchType2' => 'Toda la información',
+        'ExportHTMLSearchButton' => 'Buscar',
+        'ExportHTMLSearchTitle' => 'Mostrar sólo las películas coincidentes con los criterios anteriores',
+        'ExportHTMLAllButton' => 'Todas',
+        'ExportHTMLAllTitle' => 'Mostrar todas las películas',
+        'ExportHTMLExpand' => 'Todos desplegados',
+        'ExportHTMLExpandTitle' => 'Mostrar la información de todas las películas',
+        'ExportHTMLCollapse' => 'Todos plegados',
+        'ExportHTMLCollapseTitle' => 'Ocultar la información de todas las películas',
         'ExportHTMLBorrowed' => 'Prestatario : ',
-        'ExportHTMLnoBorrowed' => 'Disponible ',
-        'ExportHTMLtop' => 'Arriba',
-        'ExportHTMLtableTime' => 'Duración',
-        'ExportHTMLtableType' => 'Géneros',
-        'ExportHTMLtableDate' => 'Fecha de salida',
-        'ExportHTMLtableDirector' => 'Director',
-        'ExportHTMLtableActors' => 'Actores',
-        'ExportHTMLtableFormat' => 'Soporte',
-        'ExportHTMLtableRating' => 'Nota',
-        'ExportHTMLtableAudio' => 'Audio',
-        'ExportHTMLtableSubtitle' => 'Subtítulos',
-	
-        'ExportHTMLFileTemplate' => 'Plantilla :',
-        'ExportHTMLTemplateChoice' => 'Elija su plantilla',
+        'ExportHTMLNotBorrowed' => 'Disponible ',
+        'ExportHTMLTop' => 'Arriba',
 
         'ExportSQLWithPictures' => 'Copiar las imágenes a un subdirectorio',
         'ExportSQLWithDrop' => 'Incluir una instrucción DROP',
@@ -409,8 +418,10 @@ VFRMania : Contribución',
         'ImportListPlugin' => 'Sitio a usar',
         'ImportListUseFirst' => 'Seleccionar el primero si hay muchos resultados',
         'ImportListCommentAuto' => 'Película importada automáticamente.',
-        'ImportListCommentSite' => 'Sitio web: ',
-        'ImportListCommentTitle' => 'Título: ',
+        'ImportListCommentSite' => 'Sitio web : ',
+        'ImportListCommentTitle' => 'Título : ',
+
+        'ImportTellicoNotVideo' => 'El fichero no es una colección de video Tellico',
 
         'MultiSiteTitle' => 'Sitios donde buscar',
         'MultiSiteUnused' => 'Módulos no usados',
@@ -426,6 +437,7 @@ VFRMania : Contribución',
             time => 'Ficha : Duración',
             director => 'Ficha : Director',
             nat => 'Ficha : Nacionalidad',
+            age => 'Ficha : Edad mínima',
             type => 'Ficha : Géneros',
             image => 'Ficha : Imagen',
             orig => 'Ficha : Título original',
@@ -438,6 +450,10 @@ VFRMania : Contribución',
             format => 'Soporte : Géneros',
             url => 'Ficha : URL',
             place => 'Soporte : Sitio',
+            video => 'Detalles : Formato de video',
+            trailer => 'Detalles : Fichero de video',
+            collection => 'Detalles : Serie',
+            rank => 'Detalles : Capítulo',
             audio => 'Idiomas : Audio',
             subt => 'Idiomas : Subtítulos',
             borrower => 'Préstamo : Prestatario',
@@ -450,39 +466,13 @@ VFRMania : Contribución',
         'DisplayOptionsMain' => 'Elementos principales',
         'DisplayOptionsActions' => 'Botones debajo de las fichas',
         'DisplayOptionsSearch' => 'Buscar',
-        'DisplayOptionsId' => 'Identificador de película',
-        'DisplayOptionsInfo' => 'Ficha de la película',
-        'DisplayOptionsPerso' => 'Informaciones personal',
-        'DisplayOptionsBorrowings' => 'Préstamo',
-        'DisplayOptionsSeen' => 'Película ya vista',
-        'DisplayOptionsRating' => 'Nota',
-        'DisplayOptionsFormat' => 'Soporte',
-        'DisplayOptionsNumber' => 'Número',
-        'DisplayOptionsPlace' => 'Sitio',
-        'DisplayOptionsAudio' => 'Idioma audio',
-        'DisplayOptionsSubt' => 'Idioma subtítulos',
-        'DisplayOptionsComment' => 'Comentarios',
-        'DisplayOptionsOrig' => 'Título original',
-        'DisplayOptionsImage' => 'Imagen',
-        'DisplayOptionsDate' => 'Fecha de salida',
-        'DisplayOptionsDirector' => 'Director',
-        'DisplayOptionsAge' => 'Edad mínima',
-        'DisplayOptionsTime' => 'Duración',
-        'DisplayOptionsNat' => 'Nacionalidad',
-        'DisplayOptionsType' => 'Géneros',
-        'DisplayOptionsActors' => 'Actores',
-        'DisplayOptionsSynopsis' => 'Sinopsis',
-        'DisplayOptionsBorrower' => 'Prestatario',
-        'DisplayOptionsLendDate' => 'Fecha de préstamo',
-        'DisplayOptionsMail' => 'Enviar un e-mail',
-        'DisplayOptionsHistory' => 'Historial',
 
         'GenresTitle' => 'Conversión de Géneros',
         'GenresCategoryName' => 'Género a usar',
         'GenresCategoryMembers' => 'Géneros a reemplazar',
         'GenresLoad' => 'Cargar una lista predefinida',
         'GenresExport' => 'Exportar listado a un fichero',
-
+        'GenresModify' => 'Editar conversión',
     );
 }
 1;
