@@ -33,6 +33,8 @@
 
         'LangName' => 'Français',
         
+        'Separator' => ' : ',
+        
         'Warning' => '<b>Attention</b> :
         
 Les informations récupérées depuis des sites Internet
@@ -45,23 +47,32 @@ l\'<b>accord préalable</b> des sites concernés.
 Vous pourrez à tout instant connaître le site d\'où
 proviennent les informations d\'un film en cliquant sur
 le <b>bouton situé en dessous de sa fiche</b>.',
+
+        'AllMoviesFiltered' => 'Aucun film ne correspond aux critères de filtrage',
         
         'InstallDirInfo' => 'Installation dans ',
         'InstallMandatory' => 'Composants obligatoires',
         'InstallOptional' => 'Composants optionnels',
-        'InstallErrorMissing' => 'Erreur : Les composants suivants doivent être installés : ',
+        'InstallErrorMissing' => 'Erreur : Les composants Perl suivants doivent être installés : ',
         'InstallPrompt' => 'Répertoire de base pour l\'installation [/usr/local] : ',
         'InstallEnd' => 'Fin de l\'installation',
         'InstallNoError' => 'Aucune erreur',
         'InstallLaunch' => 'Pour utiliser l\'application, lancez ',
         'InstallDirectory' => 'Répertoire de base',
         'InstallTitle' => 'Installation de GCfilms',
-        'InstallDependancies' => 'Dépendances',
-        'InstallToggleDependancies' => 'Afficher/Masquer les dépendances',
+        'InstallDependencies' => 'Dépendances',
+        'InstallPath' => 'Chemin',
+        'InstallOptions' => 'Options',
         'InstallSelectDirectory' => 'Choisissez le répertoire de base pour l\'installation',
         'InstallWithClean' => 'Effacer précédents fichiers situés au même emplacement',
        	'InstallWithMenu' => 'Ajouter GCfilms au menu des applications',
        	'InstallNoPermission' => 'Erreur: Vous n\'avez pas la permission d\'écrire dans le répertoire sélectionné',
+        'InstallMissingMandatory' => 'Des dépendances obligatoires sont manquantes. Vous ne pourrez pas installer GCfilms tant qu\'elles ne seront pas installées.',
+        'InstallMissingOptional' => 'Quelques dépendances facultatives sont manquantes. Elles sont listées ci-dessous. GCfilms peut être installé mais certaines fonctionnalités ne seront pas présentes.',
+        'InstallMissingNone' => 'Aucune dépendance n\'est manquante. Vous pouvez poursuivre l\'installation de GCfilms.',
+        'InstallOK' => 'OK',
+        'InstallMissing' => 'Manquant',
+        'InstallMissingFor' => 'Manquant pour',
 
         'SplashInit' => 'Initialisation',
         'SplashLoad' => 'Chargement des films',
@@ -78,6 +89,7 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'Movies' => 'Films',
         'PreferencesTooltip' => 'Changer vos préférences',
         'ViewTooltip' => 'Changer le type de liste',
+        'PlayTooltip' => 'Lancer la lecture de la vidéo associée au film',
         
         'StatusSearch' => 'Recherche en cours...',
         'StatusGetInfo' => 'Récupération des informations...',
@@ -103,14 +115,19 @@ le <b>bouton situé en dessous de sa fiche</b>.',
         'AboutWho' => 'Tian : Gestionnaire du projet, Programmeur
 MeV : Programmeur
 Christophe Z : Programmeur
-rootII : Programmeur
+Adolfo González : Programmeur
+
+Jason Day : Contributeur
+Gabriel Meier : Contributeur
 
 Dab : Contributeur
-Jason Day : Contributeur
-Infinito : Contributeur
+rootII : Contributeur
 VFRMania : Contributeur',
-        'AboutLicense' => 'Distribué selon les termes de la GNU GPL',
+        'AboutLicense' => 'Distribué selon les termes de la GNU GPL
+Logos Copyright le Spektre
+http://le-spektre.org',
         'AboutTranslation' => 'Traduction française par Tian',
+        'AboutDesign' => 'Logo et webdesign par le Spektre',
         
         'ToolbarRandom' => 'Ce soir',
         
@@ -123,14 +140,18 @@ VFRMania : Contributeur',
 
         'OptionsTitle' => 'Préférences',
         'OptionsBrowser' => 'Navigateur web',
+        'OptionsPlayer' => 'Lecteur de vidéos',
         'OptionsImages' => 'Répertoire images',
+        'OptionsUseRelativePaths' => 'Utiliser des chemins relatifs pour les images',
         'OptionsOrder' => 'Disposition',
         'OptionsStatus' => 'Afficher la barre d\'état en bas de la fenêtre',
         'OptionsUrlPicture' => 'Afficher le logo du site sur le bouton permettant d\'ouvrir la page d\'un film',
         'OptionsWarning' => 'Attention : Les changements effectués dans cet onglet ne seront pris en compte qu\'après un redémarrage de l\'application',
         'OptionsTabs' => 'Onglets',
-        'OptionsInfo' => 'Fiche du film d\'abord',
-        'OptionsPerso' => 'Informations personnelles d\'abord',
+        'OptionsAllInOne' => 'Une seule page',
+        'OptionsCompact' => 'Compact',
+        'OptionsReadOnly' => 'Lecture seule',
+        'OptionsWebSite' => 'Site Web GCfilms',
         'OptionsRemoveConfirm' => 'Demander confirmation avant la suppression',
         'OptionsAutoSave' => 'Sauvegarde automatique de la liste de films',
         'OptionsSplash' => 'Afficher l\'écran de démarrage',
@@ -151,6 +172,8 @@ VFRMania : Contributeur',
         'OptionsDisplay' => 'Affichage',
         'OptionsToolbar' => 'Barre d\'outils',
         'OptionsToolbars' => {0 => 'Aucune', 1 => 'Petite', 2 => 'Grande'},
+        'OptionsToolbarPosition' => 'Position',
+        'OptionsToolbarPositions' => {0 => 'Haut', 1 => 'Bas', 2 => 'Gauche', 3 => 'Droite'},
         'OptionsView' => 'Affichage des films',
         'OptionsViews' => {0 => 'Texte', 1 => 'Image', 2 => 'Détaillée'},
         'OptionsColumns' => 'Colonnes',
@@ -162,19 +185,38 @@ VFRMania : Contributeur',
         'OptionsFormats' => 'Type de supports (Séparés par des virgules)',
         'OptionsSearchStop' => 'Une recherche peut être arrêtée',
         'OptionsAlwaysOriginal' => 'Utiliser le titre principal comme titre original si non présent',
-        'OptionsSelectColor' => 'Choisissez une couleur',
-        'OptionsImagesBg' => 'Fond',
-        'OptionsImagesBgPicture' => 'Utiliser une image de fond',
-        'OptionsImagesFg'=> 'Selection',
-        'OptionsImagesBgTooltip' => 'Changer la couleur et l\'image de fond',
-        'OptionsImagesFgTooltip'=> 'Changer la couleur de la sélection',
 		'OptionsHistory' => 'Taille de l\'historique',
 		'OptionsClearHistory' => 'Purger l\'historique',
 		'OptionsStyle' => 'Thème',
-		'OptionsDetailsFields' => 'Champs',
-		'OptionsDetailsTitle' => 'Choisir les champs à afficher',
+        'OptionsDontAsk' => 'Ne plus demander',
+
+        'ImagesOptionsButton' => 'Réglages',
+        'ImagesOptionsTitle' => 'Réglages pour la liste d\'images',
+        'ImagesOptionsSelectColor' => 'Choisissez une couleur',
+        'ImagesOptionsBg' => 'Fond',
+        'ImagesOptionsBgPicture' => 'Utiliser une image de fond',
+        'ImagesOptionsFg'=> 'Selection',
+        'ImagesOptionsBgTooltip' => 'Changer la couleur de fond',
+        'ImagesOptionsFgTooltip'=> 'Changer la couleur de la sélection',
+        'ImagesOptionsSizeLabel' => 'Taille',
+        'ImagesOptionsSizeList' => {0 => 'Minuscule', 1 => 'Petit', 2 => 'Moyen', 3 => 'Grand', 4 => 'Enorme'},
+        'ImagesOptionsSizeTooltip' => 'Selectionnez la taille pour les images',
+
+        'DetailedOptionsTitle' => 'Réglages pour la liste détaillée',
+        'DetailedOptionsImageSize' => 'Taille des images',
+        'DetailedOptionsGroupMovies' => 'Regrouper les films de la même série',
+		'DetailedOptionsFields' => 'Choisir les champs à afficher',
+
+        'ExtractButton' => 'Informations',
+        'ExtractTitle' => 'Informations du fichier vidéo',
+        'ExtractSize' => 'Dimensions',
+        'ExtractLength' => 'Durée (minutes)',
+        'ExtractType' => 'Format vidéo',
+        'ExtractAudioEncoding' => 'Format audio',
+        'ExtractImport' => 'Utiliser les valeurs',
 
         'ExportTitle' => 'Exporter la liste de films',
+        'ExportFilter' => 'Exporter seulement les films affichés',
         'ImportListTitle' => 'Importer une autre liste de films',
         'ImportExportFile' => 'Fichier',
         'ImportExportSave' => 'Choisissez le fichier à utiliser',
@@ -195,38 +237,23 @@ VFRMania : Contributeur',
 
         'PanelSearchButton' => 'Télécharger',
         'PanelSearchTip' => 'Rechercher les informations concernant le film dont le titre a été saisi',
-        'PanelSeen' => 'Film déjà vu',
-        'PanelRating' => 'Note : ',
-        'PanelMedia' => 'Support : ',
-        'PanelNumber' => 'Nombre : ',
-        'PanelPlace' => 'Emplacement :',
+        'PanelSeenYes' => 'Film vu',
+        'PanelSeenNo' => 'Film non vu',
         'PanelLanguages' => 'Langues',
-        'PanelAudio' => 'Audio',
         'PanelEncoding' => 'Encodage',
-        'PanelSub' => 'Sous-titres',
-        'PanelComment' => 'Commentaires :',
-        'PanelOriginal' => 'Titre original : ',
-        'PanelImageTip' => 'Cliquez sur l\'image pour en choisir une autre',
+        'PanelImageTip' => 'Cliquez sur l\'image pour en choisir une autre. Clic droit pour plus d\'options.',
         'PanelImageTitle' => 'Sélectionnez une image',
+        'PanelTrailerTitle' => 'Sélectionnez un fichier',
         'PanelInfoFrame' => 'Informations',
-        'PanelDate' => 'Date de sortie : ',
-        'PanelDirector' => 'Réalisé par : ',
-        'PanelTime' => 'Durée : ',
-        'PanelCountry' => 'Nationalité : ',
-        'PanelAge' => 'Age minimum : ',
         'PanelAgeUnknown' => 'Inconnu',
         'PanelAgeNone' => 'Aucune restriction',
         'PanelAgeParent' => 'Accord parental',
-        'PanelType' => 'Genres : ',
-        'PanelActors' => 'Acteurs : ',
-        'PanelDescription' => 'Synopsis :',
-        'PanelLendDate' => 'Date d\'emprunt',
-        'PanelBorrower' => 'Emprunteur',
         'PanelNobody' => 'Personne',
         'PanelUnknown' => 'Inconnu',
+        'PanelLendedYes' => 'Prêté',
+        'PanelLendedNo' => 'Disponible',
         'PanelLendDateSelect' => '_Changer la date',
         'PanelReturned' => 'Film _rendu',
-        'PanelHistory' => 'Historique',
         'PanelRemove' =>'S_upprimer',
         'PanelClear' =>'_Vider',
         'PanelReturnDate' => 'Date de retour',
@@ -234,7 +261,7 @@ VFRMania : Contributeur',
         'PanelWebTip' => 'Voir la fiche du film sur Internet',
         'PanelRemoveTip' => 'Supprimer le film affiché ci-dessus',
         'PanelMovieInfo' => 'Fiche du film',
-        'PanelPrivateInfo' => 'Informations personnelles',
+        'PanelPrivateInfo' => 'Détails',
         'PanelLendInfo' => 'Emprunts',
 
         'MenuNewList' => 'Nouvelle _liste de films',
@@ -263,14 +290,15 @@ VFRMania : Contributeur',
         'MenuAgeParent' => 'Avec _accord parental',
         'MenuAgeLess' => 'D\'un âge _spécifié...',
         'MenuEdit'  => '_Edition',
-		'MenuEditDeleteCurrent' => 'Su_pprimer le film courant',
-		'MenuEditLockMovies' => 'Verroui_ller les informations',
+   	    'MenuDuplicate' => '_Dupliquer le film',
+        'MenuEditDeleteCurrent' => 'Su_pprimer le film courant',
+        'MenuEditLockMovies' => 'Verroui_ller les informations',
         'MenuDisplay' => 'Fil_tres',
         'MenuConfiguration' => '_Configuration',
         'MenuDisplayOptions' => '_Informations à afficher',
         'MenuBorrowers' => '_Emprunteurs',
         'MenuGenresConversion' => 'Conversions de _genres',
-        'MenuRename' => '_Renommer une catégorie',
+        'MenuRename' => '_Renommer un genre',
         'MenuAbout' => 'A _propos de GCfilms',
         'MenuHelp' => '_?',
         'MenuNewWindow' => 'Afficher le film dans une nouvelle fenêtre',
@@ -292,11 +320,12 @@ VFRMania : Contributeur',
         'PluginsName' => 'Nom',
         'PluginsAuthor' => 'Auteur',
         'PluginsLang' => 'Langue',
+        'PluginsUseSite' => 'Utiliser le site sélectionné pour les futures recherches',
         
         'BorrowersTitle' => 'Configuration des emprunteurs',
         'BorrowersName' => 'Nom',
         'BorrowersEmail' => 'E-mail',
-        'BorrowersAdd' => '_Ajouter',
+        'BorrowersAdd' => 'Ajouter',
         'BorrowersRemove' => '_Supprimer',
         'BorrowersEdit' => '_Modifier',
         'BorrowersTemplate' => 'Modèle d\'e-mail',
@@ -329,62 +358,44 @@ VFRMania : Contributeur',
         'SearchSeenYes' => 'Oui',
         'SearchSeenNo' => 'Non',
         'SearchAge' => 'Age du public',
+        'SearchYear' => 'Année entre',
+        'SearchYearBetween' => 'et',
         
         'RenameTitle' => 'Renommer une catégorie',
         'RenameOld' => 'Nom actuel',
         'RenameNew' => 'Nouveau nom',
         
-        'ImportTitle' => 'Choisir les champs à importer',
-        'ImportMovieTitle' => 'Titre',
-        'ImportDate' => 'Date',
-        'ImportTime' => 'Durée',
-        'ImportDirector' => 'Réalisateur',
-        'ImportNat' => 'Nationalité',
-        'ImportAge' => 'Age minimum',
-        'ImportOrig' => 'Titre original',
-        'ImportActors' => 'Acteurs',
-        'ImportSynopsis' => 'Synopsis',
-        'ImportAudio' => 'Langues',
-        'ImportSubt' => 'Sous-titres',
-        'ImportImage' => 'Image',
+        'ImportWindowTitle' => 'Choisir les champs à importer',
         'ImportViewPicture' => 'Voir l\'image',
-        'ImportType' => 'Genres',
         'ImportSelectAll' => 'Tout sélectionner',
         'ImportSelectNone' => 'Ne rien sélectionner',
         
         'ExportTarGzInfo' => 'L\'archive se trouve dans le fichier : ',
 
         'ExportHTMLWithJS' => 'Utiliser du Javascript',
+        'ExportHTMLFileTemplate' => 'Modèle :',
+        'ExportHTMLPreview' => 'Aperçu',
+        'ExportHTMLNoPreview' => 'Aucun aperçu disponible',
         'ExportHTMLTitle' => 'Titre de la page',
         'ExportHTMLInfoFile' => 'La liste se trouve dans le fichier : ',
         'ExportHTMLInfoDir' => 'Les images se trouvent dans : ',
         'ExportHTMLHeightimg' => 'Hauteur en pixel de l\'image à exporter : ',
-        'ExportHTMLnote' => 'Liste générée avec <a href="https://gna.org/projects/gcfilms/">GCfilms</a>',
-        'ExportHTMLinputTitle' => 'Entrez le texte à rechercher',
-        'ExportHTMLlistSearchTypeValue1' => 'Titre seulement',
-        'ExportHTMLlistSearchTypeValue2' => 'Toutes les informations',
-        'ExportHTMLsearchbutton' => 'Rechercher',
-        'ExportHTMLsearchbuttonTitle' => 'Afficher seulement les films correspondant aux critères précédents',
-        'ExportHTMLallbutton' => 'Tous',
-        'ExportHTMLallbuttonTitle' => 'Afficher tous les films',
-        'ExportHTMLviewinfos' => 'Tout développer',
-        'ExportHTMLviewinfosTitle' => 'Afficher les informations de tous les films',
-        'ExportHTMLhideinfos' => 'Tout réduire',
-        'ExportHTMLhideinfosTitle' => 'Masquer les informations de tous les films',
+        'ExportHTMLOpenFileInBrowser' => 'Ouvrir le fichier généré dans le navigateur web',
+        'ExportHTMLNote' => 'Liste générée avec <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
+        'ExportHTMLInputTitle' => 'Entrez le texte à rechercher',
+        'ExportHTMLSearchType1' => 'Titre seulement',
+        'ExportHTMLSearchType2' => 'Toutes les informations',
+        'ExportHTMLSearchButton' => 'Rechercher',
+        'ExportHTMLSearchTitle' => 'Afficher seulement les films correspondant aux critères précédents',
+        'ExportHTMLAllButton' => 'Tous',
+        'ExportHTMLAllTitle' => 'Afficher tous les films',
+        'ExportHTMLExpand' => 'Tout développer',
+        'ExportHTMLExpandTitle' => 'Afficher les informations de tous les films',
+        'ExportHTMLCollapse' => 'Tout réduire',
+        'ExportHTMLCollapseTitle' => 'Masquer les informations de tous les films',
         'ExportHTMLBorrowed' => 'Emprunté par : ',
-        'ExportHTMLnoBorrowed' => 'Disponible',
-        'ExportHTMLtop' => 'Haut',
-        'ExportHTMLtableTime' => 'Durée',
-        'ExportHTMLtableType' => 'Genre',
-        'ExportHTMLtableDate' => 'Date de sortie',
-        'ExportHTMLtableDirector' => 'Réalisateur',
-        'ExportHTMLtableActors' => 'Acteurs',
-        'ExportHTMLtableFormat' => 'Format',
-        'ExportHTMLtableRating' => 'Note',
-        'ExportHTMLtableAudio' => 'Audio',
-        'ExportHTMLtableSubtitle' => 'Sous titre',
-	
-        'ExportHTMLFileTemplate' => 'Modèle :',
+        'ExportHTMLNotBorrowed' => 'Disponible',
+        'ExportHTMLTop' => 'Haut',
 
         'ExportSQLWithPictures' => 'Copier les images dans un sous-répertoire',
         'ExportSQLWithDrop' => 'Inclure une instruction DROP',
@@ -411,6 +422,8 @@ VFRMania : Contributeur',
         'ImportListCommentSite' => 'Site web : ',
         'ImportListCommentTitle' => 'Titre : ',
         
+        'ImportTellicoNotVideo' => 'Le fichier n\'est pas un catalogue Tellico de videos',
+        
         'MultiSiteTitle' => 'Sites où rechercher',
         'MultiSiteUnused' => 'Modules non utilisés',
         'MultiSiteUsed' => 'Modules à utiliser',
@@ -426,23 +439,27 @@ VFRMania : Contributeur',
             director => 'Informations : Réalisateur',
             nat => 'Informations : Nationalité',
             age => 'Informations : Age minimum',
-            type => 'Informations : Genre',
+            type => 'Informations : Genres',
             image => 'Informations : Image',
             orig => 'Informations : Titre original',
             actors => 'Informations : Acteurs',
             comment => 'Personnel : Commentaires',
             synopsis => 'Informations : Synopsis',
-            seen => 'Personnel : Déjà vu',
+            seen => 'Personnel : Film déjà vu',
             number => 'Support : Nombre',
             rating => 'Personnel : Note',
-            format => 'Support : Type',
+            format => 'Support : Format',
             url => 'Informations : URL de la fiche',
             place => 'Support : Emplacement',
+            video => 'Support : Format vidéo',
+            trailer => 'Détails : Fichier vidéo',
+            collection => 'Détails : Série',
+            rank => 'Détails : Rang',
             audio => 'Langues : Audio',
             subt => 'Langues : Sous-titres',
-            borrower => 'Emprunt : Nom',
-            lendDate => 'Emprunt : Date',
-            history => 'Emprunt : Historique',
+            borrower => 'Emprunt : Emprunteur',
+            lendDate => 'Emprunt : Date d\'emprunt',
+            history => 'Emprunt : Historique des emprunts',
         },
         
         'DisplayOptionsTitle' => 'Eléments à afficher',
@@ -450,38 +467,13 @@ VFRMania : Contributeur',
         'DisplayOptionsMain' => 'Principaux éléments',
         'DisplayOptionsActions' => 'Boutons sous les fiches',
         'DisplayOptionsSearch' => 'Bouton recherche',
-        'DisplayOptionsId' => 'Identifiant du film',
-        'DisplayOptionsInfo' => 'Fiche du film',
-        'DisplayOptionsPerso' => 'Informations personnelles',
-        'DisplayOptionsBorrowings' => 'Emprunts',
-        'DisplayOptionsSeen' => 'Film déjà vu',
-        'DisplayOptionsRating' => 'Note',
-        'DisplayOptionsFormat' => 'Support',
-        'DisplayOptionsNumber' => 'Nombre',
-        'DisplayOptionsPlace' => 'Emplacement',
-        'DisplayOptionsAudio' => 'Langues audio',
-        'DisplayOptionsSubt' => 'Langues sous-titres',
-        'DisplayOptionsComment' => 'Commentaires',
-        'DisplayOptionsOrig' => 'Titre original',
-        'DisplayOptionsImage' => 'Image',
-        'DisplayOptionsDate' => 'Date de sortie',
-        'DisplayOptionsDirector' => 'Réalisateur',
-        'DisplayOptionsAge' => 'Age minimum',
-        'DisplayOptionsTime' => 'Durée',
-        'DisplayOptionsNat' => 'Nationalité',
-        'DisplayOptionsType' => 'Genres',
-        'DisplayOptionsActors' => 'Acteurs',
-        'DisplayOptionsSynopsis' => 'Synopsis',
-        'DisplayOptionsBorrower' => 'Emprunteur',
-        'DisplayOptionsLendDate' => 'Date d\'emprunt',
-        'DisplayOptionsMail' => 'Envoyer un e-mail',
-        'DisplayOptionsHistory' => 'Historique',
         
         'GenresTitle' => 'Conversions de genres',
         'GenresCategoryName' => 'Genre à utiliser',
         'GenresCategoryMembers' => 'Genres à remplacer',
         'GenresLoad' => 'Charger une liste prédéfinie',
         'GenresExport' => 'Exporter la liste dans un fichier',
+        'GenresModify' => 'Changer la conversion',
     );
 }
 1;
