@@ -33,6 +33,8 @@
 
         'LangName' => 'Italiano',
         
+        'Separator' => ': ',
+        
         'Warning' => '<b>Warning</b>:
         
 Information downloaded from Internet sites (thanks to 
@@ -43,6 +45,8 @@ web sites authorisation</b>.
 
 To know which is the web site owning information, you
 can use <b>button below film details</b>.',
+        
+        'AllMoviesFiltered' => 'No movie matches your filtering criteria',
 
         'InstallDirInfo' => 'Installazione dentro ',
         'InstallMandatory' => 'Componenti obbligatori',
@@ -54,12 +58,19 @@ can use <b>button below film details</b>.',
         'InstallLaunch' => 'Per usare questa applicazione, si può lanciare ',
         'InstallDirectory' => 'Indice basso',
         'InstallTitle' => 'Installazione di GCfilms',
-        'InstallDependancies' => 'Dipendenze',
-        'InstallToggleDependancies' => 'Esposizione/Pellame dipendenze',
+        'InstallDependencies' => 'Dipendenze',
+        'InstallPath' => 'Path',
+        'InstallOptions' => 'Options',
         'InstallSelectDirectory' => 'Selezioni l\'indice basso per l\'installazione',
         'InstallWithClean' => 'Rimuovi files trovati nella directory di installazione',
        	'InstallWithMenu' => 'Add GCfilms to Applications menu',
        	'InstallNoPermission' => 'Error: You don\'t have permission to write in the selected directory',
+        'InstallMissingMandatory' => 'Mandatory dependencies are missing. You won\'t be able to install GCfilms until they have been added to your system.',
+        'InstallMissingOptional' => 'Some optional dependencies are missing. There are listed under. GCfilms may be installed but some features won\'t be available.',
+        'InstallMissingNone' => 'There are no missing dependency. You may continue and install GCfilms.',
+        'InstallOK' => 'OK',
+        'InstallMissing' => 'Missing',
+        'InstallMissingFor' => 'Missing for',
         
         'SplashInit' => 'Inizio',
         'SplashLoad' => 'Caricamento films',
@@ -76,6 +87,7 @@ can use <b>button below film details</b>.',
         'Movies' => 'Films',
         'PreferencesTooltip' => 'Imposta preferenze',
         'ViewTooltip' => 'Cambia il tipo di liste',
+        'PlayTooltip' => 'Play video associated to the movie',
 
         'StatusSearch' => 'Ricerca in progresso...',
         'StatusGetInfo' => 'Ottenere le informazioni...',
@@ -101,14 +113,19 @@ can use <b>button below film details</b>.',
         'AboutWho' => 'Tian : Gestione di progetti, Programmazione
 MeV : Programmazione
 Christophe Z : Programmazione
-rootII : Programmazione
+Adolfo González : Programmazione
 
-Dab : Programmazione
-Jason Day : Programmazione
-Infinito : Programmazione
-VFRMania : Programmazione',
-        'AboutLicense' => 'Distribuito sotto i termini dello GNU GPL',
-	'AboutTranslation' => 'Traduzione italiana da Ernic',
+Jason Day : Contribuzione
+Gabriel Meier : Contribuzione
+
+Dab : Contribuzione
+rootII : Contribuzione
+VFRMania : Contribuzione',
+        'AboutLicense' => 'Distribuito sotto i termini dello GNU GPL
+Logos Copyright le Spektre
+http://le-spektre.org',
+        'AboutTranslation' => 'Traduzione italiana da Ernic',
+        'AboutDesign' => 'Logo and webdesign by le Spektre',
 
         'ToolbarRandom' => 'Stasera',
 
@@ -121,14 +138,18 @@ VFRMania : Programmazione',
         
         'OptionsTitle' => 'Preferenze',
         'OptionsBrowser' => 'Web browser',
+        'OptionsPlayer' => 'Video player',
         'OptionsImages' => 'Indice di immagini',
+        'OptionsUseRelativePaths' => 'Use relative paths for images',
         'OptionsOrder' => 'Layout',
         'OptionsStatus' => 'Visualizza la barra di stato in fondo alla finestra',
         'OptionsUrlPicture' => 'Visualizza il logo del sito sul pulsante usato per aprire la pagina delle ricerche',
         'OptionsWarning' => 'Avvertimento:  Le opzioni cambiate in questo pannello avranno effetto dopo il riavvio dell\' applicazione',
         'OptionsTabs' => 'Etichette',
-        'OptionsInfo' => 'Informazioni generali',
-        'OptionsPerso' => 'Dettagli',
+        'OptionsAllInOne' => 'All In One',
+        'OptionsCompact' => 'Compact',
+        'OptionsReadOnly' => 'Read Only',
+        'OptionsWebSite' => 'GCfilms Website',
         'OptionsRemoveConfirm' => 'Chiedi conferma prima di rimuovere un film dalla lista',
         'OptionsAutoSave' => 'Salva automaticamente la lista dei film',
         'OptionsSplash' => 'Mostra splashscreen',
@@ -149,6 +170,8 @@ VFRMania : Programmazione',
         'OptionsDisplay' => 'Visualizzazione',
         'OptionsToolbar' => 'Toolbar',
         'OptionsToolbars' => {0 => 'Nessuno', 1 => 'Piccolo', 2 => 'Grande'},
+        'OptionsToolbarPosition' => 'Position',
+        'OptionsToolbarPositions' => {0 => 'Top', 1 => 'Bottom', 2 => 'Left', 3 => 'Right'},
         'OptionsView' => 'Movies display',
         'OptionsViews' => {0 => 'Testo', 1 => 'Immagine', 2 => 'Dettagli'},
         'OptionsColumns' => 'Colonne',
@@ -160,19 +183,38 @@ VFRMania : Programmazione',
         'OptionsFormats' => 'tipo di supporto (virgola separata)',
         'OptionsSearchStop' => 'L\'utente può arrestare una ricerca',
         'OptionsAlwaysOriginal' => 'Use main title as the original one if none present',
-        'OptionsSelectColor' => 'Seleziona un colore',
-        'OptionsImagesBg' => 'Background',
-        'OptionsImagesBgPicture' => 'Usa un\'immagine di background',
-        'OptionsImagesFg'=> 'Selezione',
-        'OptionsImagesBgTooltip' => 'Cambia colore e immagine di background',
-        'OptionsImagesFgTooltip'=> 'Cambia il colore di selezione',
         'OptionsHistory' => 'Dimensione della cronologia',
         'OptionsClearHistory' => 'Cancella cronologia',
 		'OptionsStyle' => 'Skin',
-		'OptionsDetailsFields' => 'Campi',
-		'OptionsDetailsTitle' => 'Scegli i campi da visualizzare',
+        'OptionsDontAsk' => 'Don\'t ask anymore',
+
+        'ImagesOptionsButton' => 'Settings',
+        'ImagesOptionsTitle' => 'Settings for images list',
+        'ImagesOptionsSelectColor' => 'Seleziona un colore',
+        'ImagesOptionsBg' => 'Background',
+        'ImagesOptionsBgPicture' => 'Usa un\'immagine di background',
+        'ImagesOptionsFg'=> 'Selezione',
+        'ImagesOptionsBgTooltip' => 'Cambia colore di background',
+        'ImagesOptionsFgTooltip'=> 'Cambia il colore di selezione',
+        'ImagesOptionsSizeLabel' => 'Size',
+        'ImagesOptionsSizeList' => {0 => 'Very Small', 1 => 'Small', 2 => 'Medium', 3 => 'Large', 4 => 'Extra Large'},
+        'ImagesOptionsSizeTooltip' => 'Select image size',
 		        
+        'DetailedOptionsTitle' => 'Settings for detailed list',
+        'DetailedOptionsImageSize' => 'Images size',
+        'DetailedOptionsGroupMovies' => 'Group movies by collection',
+		'DetailedOptionsFields' => 'Scegli i campi da visualizzare',
+
+        'ExtractButton' => 'Information',
+        'ExtractTitle' => 'Video file information',
+        'ExtractSize' => 'Size',
+        'ExtractLength' => 'Runtime (minutes)',
+        'ExtractType' => 'Video format',
+        'ExtractAudioEncoding' => 'Audio format',
+        'ExtractImport' => 'Use values',
+
         'ExportTitle' => 'Lista film dell\'esportazione',
+        'ExportFilter' => 'Export only displayed movies',
         'ImportListTitle' => 'Importa un\'altra lista',
         'ImportExportFile' => 'Lista',
         'ImportExportSave' => 'Seleziona la lista',
@@ -193,38 +235,23 @@ VFRMania : Programmazione',
 
         'PanelSearchButton' => 'Fetch Information',
         'PanelSearchTip' => 'Cerca informazioni secondo il titolo del film inserito',
-        'PanelSeen' => 'Già visto',
-        'PanelRating' => 'Valutazione: ',
-        'PanelMedia' => 'Supporto: ',
-        'PanelNumber' => 'Numero: ',
-        'PanelPlace' => 'Luogo:',
+        'PanelSeenYes' => 'Movie already viewed',
+        'PanelSeenNo' => 'Movie not viewed',
         'PanelLanguages' => 'Lingua',
-        'PanelAudio' => 'Audio',
         'PanelEncoding' => 'Encoding',
-        'PanelSub' => 'Sottotitoli',
-        'PanelComment' => 'Commento:',
-        'PanelOriginal' => 'Titolo originale: ',
-        'PanelImageTip' => 'Clicca sull\'immagine per sceglierne un\'altra',
+        'PanelImageTip' => 'Clicca sull\'immagine per sceglierne un\'altra. Right click for more options.',
         'PanelImageTitle' => 'Sceglie un\'immagine',
+        'PanelTrailerTitle' => 'Select a file',
         'PanelInfoFrame' => 'Informazioni',
-        'PanelDate' => 'Data: ',
-        'PanelDirector' => 'Regista: ',
-        'PanelTime' => 'Durata: ',
-        'PanelCountry' => 'Nazionalità: ',
-        'PanelAge' => 'Età minima: ',
         'PanelAgeUnknown' => 'Sconosciuto',
         'PanelAgeNone' => 'Nessuno',
         'PanelAgeParent' => 'Parent Guidance',
-        'PanelType' => 'Genere: ',
-        'PanelActors' => 'Cast: ',
-        'PanelDescription' => 'Trama :',
-        'PanelLendDate' => 'Data prestito',
-        'PanelBorrower' => 'Prestatario',
         'PanelNobody' => 'Nessuno',
         'PanelUnknown' => 'Sconosciuto',
+        'PanelLendedYes' => 'Lended',
+        'PanelLendedNo' => 'Available',
         'PanelLendDateSelect' => 'Scegli una data',
         'PanelReturned' => 'Film restituito',
-        'PanelHistory' => 'Cronologia',
         'PanelRemove' =>'Elimina',
         'PanelClear' =>'Vider',
         'PanelReturnDate' => 'Data restituzione',
@@ -261,6 +288,7 @@ VFRMania : Programmazione',
         'MenuAgeParent' => 'Richiede la presenza di un adulto',
         'MenuAgeLess' => 'Con un età di...',
 		'MenuEdit'  => 'Modifica',
+   	    'MenuDuplicate' => '_Duplicate movie',
 		'MenuEditDeleteCurrent' => 'Cancella film corrente',
 		'MenuEditLockMovies' => 'Blocca la lista',
         'MenuDisplay' => 'Visualizzazione',
@@ -291,6 +319,7 @@ VFRMania : Programmazione',
         'PluginsName' => 'Name',
         'PluginsAuthor' => 'Author',
         'PluginsLang' => 'Language',
+        'PluginsUseSite' => 'Use selected site for future searches',
 
         'BorrowersTitle' => 'Configurazione di chi prende in prestito',
         'BorrowersName' => 'Nome',
@@ -328,62 +357,44 @@ VFRMania : Programmazione',
         'SearchSeenYes' => 'Sì',
         'SearchSeenNo' => 'No',
         'SearchAge' => 'Età pubblico',
+        'SearchYear' => 'Year betweeen',
+        'SearchYearBetween' => 'and',
         
         'RenameTitle' => 'Rinomina una categoria',
         'RenameOld' => 'Nome corrente',
         'RenameNew' => 'Nuovo nome',
         
-        'ImportTitle' => 'Scegli i campi da importare',
-        'ImportMovieTitle' => 'Titolo',
-        'ImportDate' => 'Data',
-        'ImportTime' => 'Durata',
-        'ImportDirector' => 'Regista',
-        'ImportNat' => 'Nazionalità',
-        'ImportAge' => 'Età minima',
-        'ImportOrig' => 'Titolo originale',
-        'ImportActors' => 'Cast',
-        'ImportSynopsis' => 'Trama',
-        'ImportAudio' => 'Audio',
-        'ImportSubt' => 'Subtitles',
-        'ImportImage' => 'Immagine',
+        'ImportWindowTitle' => 'Scegli i campi da importare',
         'ImportViewPicture' => 'Visualizza immagine',
-        'ImportType' => 'Genere',
         'ImportSelectAll' => 'Aggiungi tutti',
         'ImportSelectNone' => 'Rimuovi tutti',
         
         'ExportTarGzInfo' => 'L\'archivio è in questo file: ',
 	
         'ExportHTMLWithJS' => 'Usa Javascript',
+        'ExportHTMLFileTemplate' => 'Mascherina :',
+        'ExportHTMLPreview' => 'Preview',
+        'ExportHTMLNoPreview' => 'No preview available',
         'ExportHTMLTitle' => 'Titolo pagina',
         'ExportHTMLInfoFile' => 'La lista dei films è nel file: ',
         'ExportHTMLInfoDir' => 'Immagini sono in: ',
         'ExportHTMLHeightimg' => 'Altezza in pixel dell\'immagine da esportare : ',
-        'ExportHTMLnote' => 'Lista generata con <a href="https://gna.org/projects/gcfilms/">GCfilms</a>',
-        'ExportHTMLinputTitle' => 'Immetti testo da cercare',
-        'ExportHTMLlistSearchTypeValue1' => 'Solo il titolo',
-        'ExportHTMLlistSearchTypeValue2' => 'Informazioni complete',
-        'ExportHTMLsearchbutton' => 'Cerca',
-        'ExportHTMLsearchbuttonTitle' => 'Visualizza solo i films trovati con il criterio precedente',
-        'ExportHTMLallbutton' => 'Tutto',
-        'ExportHTMLallbuttonTitle' => 'Visualizza tutti i films',
-        'ExportHTMLviewinfos' => 'Estendi tutto',
-        'ExportHTMLviewinfosTitle' => 'Visulizza tutte le informazioni dei films',
-        'ExportHTMLhideinfos' => 'COntrai tutto',
-        'ExportHTMLhideinfosTitle' => 'Contrai tutte le informazioni dei films',
+        'ExportHTMLOpenFileInBrowser' => 'Open generated file in web browser',
+        'ExportHTMLNote' => 'Lista generata con <a href="http://home.gna.org/gcfilms/">GCfilms</a>',
+        'ExportHTMLInputTitle' => 'Immetti testo da cercare',
+        'ExportHTMLSearchType1' => 'Solo il titolo',
+        'ExportHTMLSearchType2' => 'Informazioni complete',
+        'ExportHTMLSearchButton' => 'Cerca',
+        'ExportHTMLSearchTitle' => 'Visualizza solo i films trovati con il criterio precedente',
+        'ExportHTMLAllButton' => 'Tutto',
+        'ExportHTMLAllTitle' => 'Visualizza tutti i films',
+        'ExportHTMLExpand' => 'Estendi tutto',
+        'ExportHTMLExpandTitle' => 'Visulizza tutte le informazioni dei films',
+        'ExportHTMLCollapse' => 'Contrai tutto',
+        'ExportHTMLCollapseTitle' => 'Contrai tutte le informazioni dei films',
         'ExportHTMLBorrowed' => 'Preso in prestito da: ',
-        'ExportHTMLnoBorrowed' => 'Disponibile',
-        'ExportHTMLtop' => 'Vertice',
-        'ExportHTMLtableTime' => 'Durata',
-        'ExportHTMLtableType' => 'Genere',
-        'ExportHTMLtableDate' => 'Date',
-        'ExportHTMLtableDirector' => 'Regista',
-        'ExportHTMLtableActors' => 'Cast',
-        'ExportHTMLtableFormat' => 'Supporto',
-        'ExportHTMLtableRating' => 'Valutazione',
-        'ExportHTMLtableAudio' => 'Audio',
-        'ExportHTMLtableSubtitle' => 'Sottotitoli',
-	
-        'ExportHTMLFileTemplate' => 'Mascherina :',
+        'ExportHTMLNotBorrowed' => 'Disponibile',
+        'ExportHTMLTop' => 'Vertice',
 	
         'ExportSQLWithPictures' => 'Copia le immagini in una sub directory',
         'ExportSQLWithDrop' => 'Includi DROP instruction',
@@ -410,6 +421,8 @@ VFRMania : Programmazione',
         'ImportListCommentSite' => 'Website: ',
         'ImportListCommentTitle' => 'Title: ',
 
+        'ImportTellicoNotVideo' => 'File is not a Tellico video collection',
+
         'MultiSiteTitle' => 'Sito da usare per le ricerche',
         'MultiSiteUnused' => 'Plugins inutilizzati',
         'MultiSiteUsed' => 'Plugins da usare',
@@ -424,6 +437,7 @@ VFRMania : Programmazione',
             time => 'Informazione: Dureta',
             director => 'Informazione: Regista',
             nat => 'Informazione: Nazionalità',
+            age => 'Informazione: Età minima',
             type => 'Informazione: Genere',
             image => 'Informazione: Immagine',
             orig => 'Informazione: Titolo originale',
@@ -436,6 +450,10 @@ VFRMania : Programmazione',
             format => 'Supporto: Tipo',
             url => 'Informazione: URL',
             place => 'Supporto: Luogo',
+            video => 'Details: Video format',
+            trailer => 'Détails : Video file',
+            collection => 'Details: Collection',
+            rank => 'Details: Rank',
             audio => 'Lingue: Audio',
             subt => 'Lingue: Sottotitoli',
             borrower => 'Prestiti: Nome',
@@ -448,39 +466,13 @@ VFRMania : Programmazione',
         'DisplayOptionsMain' => 'Oggetti principali',
         'DisplayOptionsActions' => 'Bottone azione',
         'DisplayOptionsSearch' => 'Bottone ricerche',
-        'DisplayOptionsId' => 'Movie identifier',
-        'DisplayOptionsInfo' => 'Informazoni Films',
-        'DisplayOptionsPerso' => 'Informazioni private',
-        'DisplayOptionsBorrowings' => 'Informazioni di chi prende in prestito',
-        'DisplayOptionsSeen' => 'Già visto',
-        'DisplayOptionsRating' => 'Valutazione',
-        'DisplayOptionsFormat' => 'Supporto',
-        'DisplayOptionsNumber' => 'Numero',
-        'DisplayOptionsPlace' => 'Luogo',
-        'DisplayOptionsAudio' => 'Lingue audio',
-        'DisplayOptionsSubt' => 'Lingue sottotitoli',
-        'DisplayOptionsComment' => 'Commento',
-        'DisplayOptionsOrig' => 'Titolo originale',
-        'DisplayOptionsImage' => 'Immagine',
-        'DisplayOptionsDate' => 'Data',
-        'DisplayOptionsDirector' => 'Regista',
-        'DisplayOptionsAge' => 'Età minima',
-        'DisplayOptionsTime' => 'Durata',
-        'DisplayOptionsNat' => 'Nazionalità',
-        'DisplayOptionsType' => 'Genere',
-        'DisplayOptionsActors' => 'Cast',
-        'DisplayOptionsSynopsis' => 'Trama',
-        'DisplayOptionsBorrower' => 'Prestatario',
-        'DisplayOptionsLendDate' => 'Data prestito',
-        'DisplayOptionsMail' => 'Manda un\' email',
-        'DisplayOptionsHistory' => 'Cronologia',        
 
         'GenresTitle' => 'Genre Conversion',
         'GenresCategoryName' => 'Genre to use',
         'GenresCategoryMembers' => 'Genre to replace',
         'GenresLoad' => 'Load a list',
         'GenresExport' => 'Save list to a file',
-
+        'GenresModify' => 'Edit conversion',
     );
 }
 1;
