@@ -25,18 +25,17 @@
 
     use strict;
     
-    use File::Basename;
-    use FindBin qw($RealBin);
-
- 	use base 'Exporter';
-	our @EXPORT = qw(%pluginsMap @pluginsNameArray);
-
+    use base 'Exporter';
+    our @EXPORT = qw(%pluginsMap @pluginsNameArray);
+    
     our %pluginsMap;
+    our @pluginsNameArray;
 
     use Cwd;
+    use File::Basename;
+    use FindBin qw($RealBin);
     my $oldCwd = getcwd;
     chdir $RealBin;
-
     foreach (glob "../lib/gcfilms/GCPlugins/*.pm")
     {
         my $plugin = basename($_, '.pm')."\n";
@@ -45,13 +44,11 @@
         (my $class = $plugin) =~ s/^GC/GCPlugin/;
         my $obj;
         eval "\$obj = new GCPlugins::$class";
-        die "Fatal error with plugin $plugin" if $@;
-        #push @pluginsArray, $obj;
+        die "Fatal error with plugin $plugin : $@" if $@;
         $pluginsMap{$obj->getName} = $obj;
     }
+    @pluginsNameArray = sort keys %pluginsMap;
     chdir $oldCwd;
-
-    our @pluginsNameArray = sort keys %pluginsMap;
     
     {
         package GCPluginJob;
@@ -124,52 +121,69 @@
 	    sub show
 	    {
 	        my $self = shift;
+	        $self->{useThisSite}->set_active(0);
 	        $self->SUPER::show();
 	        $self->show_all;
+	        my $path = $self->{pluginsList}->get_selection->get_selected_rows;
+		    $self->{pluginsList}->scroll_to_cell($path) if $path;
+	        
 	        my $response = $self->run;
 	        $self->{plugin} = undef;
 	        if ($response eq 'ok')
 	        {
 	            my $pluginName = '';
-	            
 	            my $idx = ($self->{pluginsList}->get_selected_indices)[0];
-	            
-                $pluginName = $self->{pluginsList}->{data}->[$idx]->[1];
-
+                $pluginName = $self->{pluginsList}->{data}->[$idx]->[0 + $self->{withPics}];
 	            $self->{plugin} = $pluginsMap{$pluginName};
+
+	            if ($self->{useThisSite}->get_active)
+	            {
+	               $self->{parent}->{options}->plugin($pluginName);
+	               $self->{parent}->checkPlugin;
+	            }
 	        }
 	        $self->hide;
 	    }
 	    
 	    sub new
 	    {
-	        my ($proto, $parent) = @_;
-	        my $class = ref($proto) || $proto;
-	        my $self  = $class->SUPER::new($parent->{lang}->{PluginsTitle},
-	                              $parent,
-	                              [qw/modal destroy-with-parent/],
-	                              @GCDialogs::okCancelButtons
-	                              );
-
-	        bless ($self, $class);
-	
-	        $self->{parent} = $parent;
-	
-	        $self->{query} = new Gtk2::Entry();
-	        $self->vbox->pack_start($self->{query}, 0, 0, 10);
-		
-	        my $pluginGroup = undef;
-	        my $pluginsFrame = new Gtk2::Frame($parent->{lang}->{PluginsFrame});
-	        $pluginsFrame->set_border_width(5);
-	        
-	        $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsLogo} => "pixbuf",
-                                                        $parent->{lang}->{PluginsName} => "text",
-                                                        $parent->{lang}->{PluginsLang} => "text",
-                                                        $parent->{lang}->{PluginsAuthor} => "text",);
-	        $self->{pluginsList}->set_border_width(5);
-	        $self->{pluginsList}->set_rules_hint(1);
-	        $self->{pluginsList}->get_column(0)->set_min_width(150);
-	        for my $i (0..3)
+            my ($proto, $parent) = @_;
+            my $class = ref($proto) || $proto;
+            my $self  = $class->SUPER::new($parent->{lang}->{PluginsTitle},
+                                  $parent,
+                                  [qw/modal destroy-with-parent/],
+                                  @GCDialogs::okCancelButtons
+                                  );
+    
+    	        bless ($self, $class);
+    
+            $self->{parent} = $parent;
+            $self->{withPics} = $parent->{hasPluginsPictures};
+    
+            $self->{query} = new Gtk2::Entry();
+            $self->vbox->pack_start($self->{query}, 0, 0, 10);
+    	
+            my $pluginGroup = undef;
+            my $pluginsFrame = new Gtk2::Frame($parent->{lang}->{PluginsFrame});
+            $pluginsFrame->set_border_width(5);
+            
+            if ($self->{withPics})
+            {
+                $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsLogo} => "pixbuf",
+                                                            $parent->{lang}->{PluginsName} => "text",
+                                                            $parent->{lang}->{PluginsLang} => "text",
+                                                            $parent->{lang}->{PluginsAuthor} => "text",);
+            }
+            else
+            {
+                $self->{pluginsList} = new Gtk2::SimpleList($parent->{lang}->{PluginsName} => "text",
+                                                            $parent->{lang}->{PluginsLang} => "text",
+                                                            $parent->{lang}->{PluginsAuthor} => "text",);
+            }
+            $self->{pluginsList}->set_border_width(5);
+            $self->{pluginsList}->set_rules_hint(1);
+            $self->{pluginsList}->get_column(0)->set_min_width(150);
+            for my $i (0..2)
             {
                 $self->{pluginsList}->get_column($i)->set_resizable(1);
             }
@@ -177,19 +191,23 @@
                 $self->response('ok');
             });
 
-	        $self->setPluginsList;
-	
-	        my $scrollPanelList = new Gtk2::ScrolledWindow;
-	        $scrollPanelList->set_border_width(5);
-	        $scrollPanelList->set_policy ('never', 'automatic');
-	        $scrollPanelList->set_shadow_type('etched-in');
-	        $scrollPanelList->add($self->{pluginsList});
+            $self->{currentPluginList} = undef;
 
-	        $pluginsFrame->add($scrollPanelList);
+            $self->setPluginsList;
 	
-	        $self->vbox->pack_start($pluginsFrame, 1, 1, 10);
+            my $scrollPanelList = new Gtk2::ScrolledWindow;
+            $scrollPanelList->set_border_width(5);
+            $scrollPanelList->set_policy ('never', 'automatic');
+            $scrollPanelList->set_shadow_type('etched-in');
+            $scrollPanelList->add($self->{pluginsList});
+
+            $pluginsFrame->add($scrollPanelList);
+            $self->vbox->pack_start($pluginsFrame, 1, 1, 10);
 	        
-	        $self->set_default_size(1,550);
+            $self->{useThisSite} = Gtk2::CheckButton->new($parent->{lang}->{PluginsUseSite});
+            $self->vbox->pack_start($self->{useThisSite}, 0, 0, 5);
+	        
+            $self->set_default_size(1,550);
 	        
 	        return $self;
 	    }
@@ -214,6 +232,9 @@
 	        my $list = shift;
             my @plugins_array = sort split (",", $list) if $list;
 
+            return if $list && ($self->{currentPluginList} eq $list);
+            $self->{currentPluginList} = $list;
+
 	        my $pluginGroup = undef;
             my $i = 0;
             my @newData;
@@ -222,8 +243,17 @@
 	            my $plugin = $GCPlugins::pluginsMap{$_};
                 if ((!$list) || ($plugin->getName eq $plugins_array[$i]))
                 {
-	          	 	my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($ENV{GCF_SHARE_DIR}.'/plugins/'.$plugin->getImageFile);
-	          	 	push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                    if ($self->{withPics})
+                    {
+                        my $picFile = $self->{parent}->{pluginsPicturesDir}.$plugin->getImageFile;
+                        $picFile = $ENV{GCF_SHARE_DIR}.'/icons/gcfilms_32x32.png' if ! -f $picFile;
+	          	 	    my $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($picFile);
+    	          	 	push @newData, [$pixbuf, $plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                    }
+                    else
+                    {
+    	          	 	push @newData, [$plugin->getName, "\n".$plugin->getLang."\n", $plugin->getAuthor];
+                    }
 	          	 	
                     $i++;
                 }
@@ -635,19 +665,13 @@
         else
         {
             my $ignore = $self->{parent}->{ignoreString};
-            $self->{info}->{title} = $ignore if ! $self->{titleCb}->get_active;
-            $self->{info}->{orig} = $ignore if ! $self->{origCb}->get_active;
-            $self->{info}->{date} = $ignore if ! $self->{dateCb}->get_active;
-            $self->{info}->{time} = $ignore if ! $self->{timeCb}->get_active;
-            $self->{info}->{director} = $ignore if ! $self->{directorCb}->get_active;
-            $self->{info}->{nat} = $ignore if ! $self->{natCb}->get_active;
-            $self->{info}->{age} = $ignore if ! $self->{ageCb}->get_active;
-            $self->{info}->{type} = $ignore if ! $self->{typeCb}->get_active;
-            $self->{info}->{actors} = $ignore if ! $self->{actorsCb}->get_active;
-            $self->{info}->{synopsis} = $ignore if ! $self->{synopsisCb}->get_active;
-            $self->{info}->{image} = $ignore if ! $self->{imageCb}->get_active;
-            $self->{info}->{audio} = $ignore if ! $self->{audioCb}->get_active;
-            $self->{info}->{subt} = $ignore if ! $self->{subtCb}->get_active;
+            
+            foreach my $field(@{$self->{parent}->{movies}->{fields}})
+            {
+                next if ! $self->{parent}->{movies}->{fieldsInfo}->{$field}->{isImported};
+                next if ($field eq 'url');
+                $self->{info}->{$field} = $ignore if ! $self->{$field.'Cb'}->get_active;
+            }            
 
             return $self->{info};
         }
@@ -699,7 +723,7 @@
     {
         my ($proto, $parent) = @_;
         my $class = ref($proto) || $proto;
-        my $self  = $class->SUPER::new($parent->{lang}->{ImportTitle},
+        my $self  = $class->SUPER::new($parent->{lang}->{ImportWindowTitle},
                               $parent,
                               [qw/modal destroy-with-parent/],
                               @GCDialogs::okCancelButtons
@@ -718,89 +742,35 @@
         $self->{table}->set_col_spacings(10);
         $self->{table}->set_border_width(20);
         
-        $self->{titleCb} = new Gtk2::CheckButton($parent->{lang}->{ImportMovieTitle});
-        $self->{title} = new Gtk2::Entry;
-        $self->{title}->set_editable(0);
+        my $row = 0;
+        
+        foreach my $field(@{$self->{parent}->{movies}->{fields}})
+        {
+            next if ! $self->{parent}->{movies}->{fieldsInfo}->{$field}->{isImported};
+            next if ($field eq 'image') || ($field eq 'url');
+            $self->{$field.'Cb'} = new Gtk2::CheckButton($parent->{lang}->{Displayed}->{$field});
+            $self->{$field} = new Gtk2::Entry;
+            $self->{$field}->set_editable(0);
+            $self->{table}->attach($self->{$field.'Cb'}, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+            $self->{table}->attach($self->{$field}, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+            $row++;
+        }
+        
         $self->{title}->set_width_chars(50);
-        $self->{table}->attach($self->{titleCb}, 0, 1, 0, 1, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{title}, 1, 2, 0, 1, 'fill', 'fill', 0, 0);
-
-        $self->{origCb} = new Gtk2::CheckButton($parent->{lang}->{ImportOrig});
-        $self->{orig} = new Gtk2::Entry;
-        $self->{orig}->set_editable(0);
-        $self->{table}->attach($self->{origCb}, 0, 1, 1, 2, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{orig}, 1, 2, 1, 2, 'fill', 'fill', 0, 0);
-
-        $self->{dateCb} = new Gtk2::CheckButton($parent->{lang}->{ImportDate});
-        $self->{date} = new Gtk2::Entry;
-        $self->{date}->set_editable(0);
-        $self->{table}->attach($self->{dateCb}, 0, 1, 2, 3, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{date}, 1, 2, 2, 3, 'fill', 'fill', 0, 0);
-
-        $self->{timeCb} = new Gtk2::CheckButton($parent->{lang}->{ImportTime});
-        $self->{time} = new Gtk2::Entry;
-        $self->{time}->set_editable(0);
-        $self->{table}->attach($self->{timeCb}, 0, 1, 3, 4, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{time}, 1, 2, 3, 4, 'fill', 'fill', 0, 0);
- 
-        $self->{directorCb} = new Gtk2::CheckButton($parent->{lang}->{ImportDirector});
-        $self->{director} = new Gtk2::Entry;
-        $self->{director}->set_editable(0);
-        $self->{table}->attach($self->{directorCb}, 0, 1, 4, 5, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{director}, 1, 2, 4, 5, 'fill', 'fill', 0, 0);
-
-        $self->{natCb} = new Gtk2::CheckButton($parent->{lang}->{ImportNat});
-        $self->{nat} = new Gtk2::Entry;
-        $self->{nat}->set_editable(0);
-        $self->{table}->attach($self->{natCb}, 0, 1, 5, 6, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{nat}, 1, 2, 5, 6, 'fill', 'fill', 0, 0);
-
-        $self->{ageCb} = new Gtk2::CheckButton($parent->{lang}->{ImportAge});
-        $self->{age} = new Gtk2::Entry;
-        $self->{age}->set_editable(0);
-        $self->{table}->attach($self->{ageCb}, 0, 1, 6, 7, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{age}, 1, 2, 6, 7, 'fill', 'fill', 0, 0);
         
-        $self->{typeCb} = new Gtk2::CheckButton($parent->{lang}->{ImportType});
-        $self->{type} = new Gtk2::Entry;
-        $self->{type}->set_editable(0);
-        $self->{table}->attach($self->{typeCb}, 0, 1, 7, 8, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{type}, 1, 2, 7, 8, 'fill', 'fill', 0, 0);
-        
-        $self->{actorsCb} = new Gtk2::CheckButton($parent->{lang}->{ImportActors});
-        $self->{actors} = new Gtk2::Entry;
-        $self->{actors}->set_editable(0);
-        $self->{table}->attach($self->{actorsCb}, 0, 1, 8, 9, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{actors}, 1, 2, 8, 9, 'fill', 'fill', 0, 0);
- 
-        $self->{synopsisCb} = new Gtk2::CheckButton($parent->{lang}->{ImportSynopsis});
-        $self->{synopsis} = new Gtk2::Entry;
-        $self->{synopsis}->set_editable(0);
-        $self->{table}->attach($self->{synopsisCb}, 0, 1, 9, 10, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{synopsis}, 1, 2, 9, 10, 'fill', 'fill', 0, 0);
-
-        $self->{audioCb} = new Gtk2::CheckButton($parent->{lang}->{ImportAudio});
-        $self->{audio} = new Gtk2::Entry;
-        $self->{audio}->set_editable(0);
-        $self->{table}->attach($self->{audioCb}, 0, 1, 10, 11, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{audio}, 1, 2, 10, 11, 'fill', 'fill', 0, 0);
-
-        $self->{subtCb} = new Gtk2::CheckButton($parent->{lang}->{ImportSubt});
-        $self->{subt} = new Gtk2::Entry;
-        $self->{subt}->set_editable(0);
-        $self->{table}->attach($self->{subtCb}, 0, 1, 11, 12, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{subt}, 1, 2, 11, 12, 'fill', 'fill', 0, 0);
-        
-        $self->{imageCb} = new Gtk2::CheckButton($parent->{lang}->{ImportImage});
+        $self->{imageCb} = new Gtk2::CheckButton($parent->{lang}->{Displayed}->{image});
         $self->{image} = new Gtk2::Entry;
         $self->{image}->set_editable(0);
-        $self->{table}->attach($self->{imageCb}, 0, 1, 12, 13, 'fill', 'fill', 0, 0);
-        $self->{table}->attach($self->{image}, 1, 2, 12, 13, 'fill', 'fill', 0, 0);
+        $self->{table}->attach($self->{imageCb}, 0, 1, $row, $row + 1, 'fill', 'fill', 0, 0);
+        $self->{table}->attach($self->{image}, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+
         $self->{buttonImage} = new Gtk2::Button($parent->{lang}->{ImportViewPicture});
         $self->{buttonImage}->signal_connect('clicked' => sub {
                 $self->showImage;
         });
-        $self->{table}->attach($self->{buttonImage}, 1, 2, 12, 13, 'fill', 'fill', 0, 0);
+        $self->{table}->attach($self->{buttonImage}, 1, 2, $row, $row + 1, 'fill', 'fill', 0, 0);
+
+        $row++;
 
         my $button1 = new Gtk2::Button($parent->{lang}->{ImportSelectAll});
         $button1->signal_connect('clicked' => sub {
@@ -813,7 +783,8 @@
                    $_->set_active(1) if $i % 2;
                 }
         });
-        $self->{table}->attach($button1, 0, 1, 13, 14, 'expand', 'fill', 0, 0);
+        $self->{table}->attach($button1, 0, 1, $row, $row + 1, 'expand', 'fill', 0, 0);
+        $row++;
         my $button2 = new Gtk2::Button($parent->{lang}->{ImportSelectNone});
         $button2->signal_connect('clicked' => sub {
                 my @children = $self->{table}->get_children;
@@ -825,7 +796,7 @@
                    $_->set_active(0) if $i % 2;
                 }
         });
-        $self->{table}->attach($button2, 0, 1, 14, 15, 'expand', 'fill', 0, 0);
+        $self->{table}->attach($button2, 0, 1, $row, $row + 1, 'expand', 'fill', 0, 0);
 
 
         my $scrollPanelList = new Gtk2::ScrolledWindow;
